IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'costeo_porcentaje')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE dbo.costeo_porcentaje
            (
              empresa NUMERIC(4, 0) NOT NULL ,
              codigo NUMERIC(8, 0) NOT NULL ,
              centro VARCHAR(15) NOT NULL ,
              tiponom INT NOT NULL ,
              periodo INT NOT NULL ,
              ayo_operacion INT NOT NULL ,
              tipo VARCHAR(3) NULL ,
              porcentaje INT ,
              serial BIGINT NOT NULL ,
              modificado VARCHAR(1)
                NULL
                CONSTRAINT PK7776
                PRIMARY KEY NONCLUSTERED
                ( empresa, codigo, centro, tiponom, periodo, ayo_operacion, serial )
            )

    END

GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'costeo_parametros')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN

        CREATE TABLE dbo.costeo_parametros
            (
              empresa NUMERIC(4, 0) NOT NULL ,
              por INT NOT NULL ,
              tipo INT NOT NULL PRIMARY KEY NONCLUSTERED ( empresa )
            )

    END

GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'costeo_ultimosRecosteados')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
--DROP TABLE dbo.costeo_ultimosRecosteados
        CREATE TABLE dbo.costeo_ultimosRecosteados
            (
              empresa NUMERIC(4, 0) NOT NULL ,
              codigo INT NOT NULL ,
              tiponom INT NOT NULL ,
              centro VARCHAR(15) NOT NULL ,
              porcentaje INT NOT NULL ,
              tipo VARCHAR(3) NOT NULL ,
              serial BIGINT
                NOT NULL
                PRIMARY KEY NONCLUSTERED
                ( empresa, codigo, centro, porcentaje )
            )

    END

GO

IF OBJECT_ID('dbo.ObtenEmpresas') IS NOT NULL 
    DROP PROCEDURE dbo.ObtenEmpresas
go

CREATE PROCEDURE dbo.ObtenEmpresas
    WITH ENCRYPTION
AS 
    SELECT  LTRIM(RTRIM(STR(empresa))) AS empresa ,
            CASE WHEN ISNULL(LEN(referencia), 0) <= 0 THEN nombre_empresa
                 ELSE referencia
            END AS nombreEmpresa
    FROM    empresas

GO

IF OBJECT_ID('dbo.ObtenDetalleEmpresaHistoricos') IS NOT NULL 
    DROP PROCEDURE dbo.ObtenDetalleEmpresaHistoricos
go

CREATE PROCEDURE dbo.ObtenDetalleEmpresaHistoricos
    (
      @companyId udtInteger
    )
    WITH ENCRYPTION
AS 
    SELECT  nombre_empresa ,
            rfc_empresa ,
            registro_patronal ,
            SUBSTRING(registro_patronal, LEN(registro_patronal), 1) AS dig ,
            mes_operacion ,
            ayo_operacion
    FROM    empresas
    WHERE   empresa = @companyId 

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RecosteoParametros')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RecosteoParametros
GO


CREATE PROCEDURE dbo.Obten_RecosteoParametros ( @empresa udtInteger )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    
    SELECT  ISNULL(tipo, 1) AS Tipo ,
            ISNULL(por, 1) AS RecosteoPor
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Agrega_RecosteoParametros')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Agrega_RecosteoParametros
GO


CREATE PROCEDURE dbo.Agrega_RecosteoParametros
    (
      @empresa udtInteger ,
      @tipo udtInteger ,
      @recosteoPor udtInteger 
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    
    IF EXISTS ( SELECT  *
                FROM    dbo.costeo_parametros
                WHERE   empresa = @empresa ) 
        BEGIN
            UPDATE  dbo.costeo_parametros
            SET     tipo = @tipo ,
                    por = @recosteoPor
            WHERE   empresa = @empresa
        END
    ELSE 
        BEGIN
            INSERT  INTO dbo.costeo_parametros
                    ( empresa, por, tipo )
            VALUES  ( @empresa, @recosteoPor, @tipo )
        END
    
GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RescosteoTiposNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RescosteoTiposNomina
GO


CREATE PROCEDURE dbo.Obten_RescosteoTiposNomina ( @empresa udtInteger )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  '0' + LTRIM(STR(k.tiponom)) + ' '
            + CASE WHEN k.tiponom = 1 THEN 'SEMANAL'
                   WHEN k.tiponom = 2 THEN 'DECENAL'
                   WHEN k.tiponom = 3 THEN 'CATORCENAL'
                   WHEN k.tiponom = 4 THEN 'QUINCENAL'
                   WHEN k.tiponom = 5 THEN 'MENSUAL'
                   WHEN k.tiponom = 6 THEN 'ESPECIAL'
              END AS 'Tipo de Nomina'
    FROM    dbo.kardex_anual AS k
    WHERE   k.empresa = @empresa
			AND k.nomina = 'ORD'
    GROUP BY k.tiponom

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RescosteoPeriodos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RescosteoPeriodos
GO


CREATE PROCEDURE dbo.Obten_RescosteoPeriodos
    (
      @empresa udtInteger ,
      @tiponom udtInteger 
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    DECLARE @tipo udtInteger

    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa

    IF @tipo = 1 
        BEGIN
            SELECT  SUBSTRING(k.mes, 1, 3) + ' ' + LTRIM(STR(k.ayo_operacion)) AS Periodo
            FROM    dbo.kardex_anual AS k
            WHERE   k.empresa = @empresa
                    AND k.tiponom = @tiponom
                    AND k.nomina='ORD'
            GROUP BY k.mes ,
                    k.ayo_operacion
            ORDER BY k.ayo_operacion DESC ,
                    CASE WHEN SUBSTRING(k.mes, 1, 3) = 'ENE' THEN 01
                         WHEN SUBSTRING(k.mes, 1, 3) = 'FEB' THEN 02
                         WHEN SUBSTRING(k.mes, 1, 3) = 'MAR' THEN 03
                         WHEN SUBSTRING(k.mes, 1, 3) = 'ABR' THEN 04
                         WHEN SUBSTRING(k.mes, 1, 3) = 'MAY' THEN 05
                         WHEN SUBSTRING(k.mes, 1, 3) = 'JUN' THEN 06
                         WHEN SUBSTRING(k.mes, 1, 3) = 'JUL' THEN 07
                         WHEN SUBSTRING(k.mes, 1, 3) = 'AGO' THEN 08
                         WHEN SUBSTRING(k.mes, 1, 3) = 'SEP' THEN 09
                         WHEN SUBSTRING(k.mes, 1, 3) = 'OCT' THEN 10
                         WHEN SUBSTRING(k.mes, 1, 3) = 'NOV' THEN 11
                         WHEN SUBSTRING(k.mes, 1, 3) = 'DIC' THEN 12
                         ELSE 0
                    END DESC 
        END 
			
    ELSE 
        BEGIN
            SELECT  REPLICATE('0', 3 - LEN(LTRIM(STR(k.periodo))))
                    + LTRIM(STR(k.periodo)) + ' ' + LTRIM(STR(k.ayo_operacion)) AS Periodo
            FROM    dbo.kardex_anual AS k
            WHERE   k.empresa = @empresa
                    AND k.tiponom = @tiponom
                    AND k.nomina = 'ORD'
            GROUP BY k.periodo ,
                    k.ayo_operacion
            ORDER BY k.ayo_operacion DESC ,
                    k.periodo DESC 
        END

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RescosteoRevisaInfo')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RescosteoRevisaInfo
GO


CREATE PROCEDURE dbo.Obten_RescosteoRevisaInfo
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @periodo udtInteger ,
      @ao udtInteger
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    DECLARE @tipo udtInteger ,
        @cTipo udtName

    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END
    
    IF EXISTS ( SELECT TOP 1
                        *
                FROM    dbo.costeo_porcentaje
                WHERE   empresa = @empresa
                        AND periodo = @periodo
                        AND ayo_operacion = @ao
                        AND tiponom = @tiponom
                        AND tipo = @cTipo ) 
        BEGIN
            SELECT  'SI' AS Res
        END
    ELSE 
        BEGIN
            SELECT  'NO' AS Res
        END


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_EmpleadosPorPeriodo')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_EmpleadosPorPeriodo
GO


CREATE PROCEDURE dbo.Obten_EmpleadosPorPeriodo
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @periodo udtInteger ,
      @ao udtInteger
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    DECLARE @tipo udtInteger ,
        @cTipo udtName

    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END

    SELECT  a.codigo AS 'Codigo' ,
            RTRIM(b.ap_paterno) + ' ' + RTRIM(b.ap_materno) + ' '
            + RTRIM(b.nombre) AS 'Nombre' ,
            SUM(CASE WHEN a.serial > 1 THEN a.porcentaje
                     ELSE 0
                END) AS '% Recosteado' ,
            SUM(CASE WHEN a.serial = 1 THEN a.porcentaje
                     ELSE 0
                END) AS 'Disponible'
    FROM    dbo.costeo_porcentaje AS a
            INNER JOIN dbo.empleados AS b ON a.empresa = b.empresa
                                             AND a.codigo = b.codigo
    WHERE   a.empresa = @empresa
            AND a.tiponom = @tiponom
            AND a.periodo = @periodo
            AND a.ayo_operacion = @ao
            AND a.tipo = @cTipo
    GROUP BY a.codigo ,
            RTRIM(b.ap_paterno) + ' ' + RTRIM(b.ap_materno) + ' '
            + RTRIM(b.nombre)
    ORDER BY a.codigo

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_EmpleadosPorPeriodoDetalle')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_EmpleadosPorPeriodoDetalle
GO


CREATE PROCEDURE dbo.Obten_EmpleadosPorPeriodoDetalle
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @periodo udtInteger ,
      @ao udtInteger
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    DECLARE @tipo udtInteger ,
        @cTipo udtName

    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END

    SELECT  RTRIM(a.centro) + ' ' + RTRIM(b.nomdepto) AS 'Departamento' ,
            a.porcentaje AS 'Porcentaje' ,
            a.serial AS 'Serial'
    FROM    dbo.costeo_porcentaje AS a
            INNER JOIN dbo.centros AS b ON a.empresa = b.empresa
                                           AND a.centro = b.centro
    WHERE   a.empresa = @empresa
            AND a.codigo = @codigo
            AND a.periodo = @periodo
            AND a.ayo_operacion = @ao
            AND a.tipo = @cTipo
    ORDER BY a.codigo ,
            a.serial

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RecosteoCentrosDisponibles')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RecosteoCentrosDisponibles
GO


CREATE PROCEDURE dbo.Obten_RecosteoCentrosDisponibles
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @periodo udtInteger ,
      @ao udtInteger
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    DECLARE @tipo udtInteger ,
        @cTipo udtName

    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END

    SELECT  RTRIM(a.centro) + ' ' + RTRIM(a.nomdepto) AS Departamento ,
            LEN(a.centro) AS longDep
    FROM    dbo.centros AS a
    WHERE   NOT a.centro IN ( SELECT    centro
                              FROM      dbo.costeo_porcentaje
                              WHERE     empresa = @empresa
                                        AND codigo = @codigo
                                        AND periodo = @periodo
                                        AND ayo_operacion = @ao
                                        AND tipo = @cTipo )
            --AND ( a.centro <> ''
            --      OR a.centro = '99999999999997'
            --    )
			and a.defindpto2<>''
            AND a.empresa = @empresa
    ORDER BY a.centro
                                        
                                        
                                        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Agrega_RecosteoCentro')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Agrega_RecosteoCentro
GO


CREATE PROCEDURE dbo.Agrega_RecosteoCentro
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @periodo udtInteger ,
      @ao udtInteger ,
      @porcentaje udtInteger ,
      @centro udtName
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    DECLARE @tipo udtInteger ,
        @cTipo udtName ,
        @Serial udtInteger

    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END

    SET @Serial = ISNULL(( SELECT   MAX(serial)
                           FROM     dbo.costeo_porcentaje
                           WHERE    empresa = @empresa
                                    AND codigo = @codigo
                                    AND periodo = @periodo
                                    AND ayo_operacion = @ao
                                    AND tipo = @cTipo
                         ), 0) + 1 
                         
                         
    INSERT  INTO dbo.costeo_porcentaje
            ( empresa ,
              codigo ,
              centro ,
              tiponom ,
              periodo ,
              ayo_operacion ,
              tipo ,
              porcentaje ,
              serial ,
              modificado
	        
            )
            SELECT  empresa ,
                    codigo ,
                    @centro ,
                    tiponom ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    @porcentaje ,
                    @serial ,
                    'S'
            FROM    dbo.costeo_porcentaje
            WHERE   empresa = @empresa
                    AND codigo = @codigo
                    AND periodo = @periodo
                    AND ayo_operacion = @ao
                    AND tipo = @cTipo
                    AND serial = 1
                                    
    UPDATE  dbo.costeo_porcentaje
    SET     modificado = 'S' ,
            porcentaje = porcentaje - @porcentaje
    WHERE   empresa = @empresa
            AND codigo = @codigo
            AND periodo = @periodo
            AND ayo_operacion = @ao
            AND tipo = @cTipo
            AND serial = 1
                                    
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Elimina_RecosteoCentro')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Elimina_RecosteoCentro
GO


CREATE PROCEDURE dbo.Elimina_RecosteoCentro
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @periodo udtInteger ,
      @ao udtInteger ,
      @porcentaje udtInteger ,
      @serial udtInteger
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    DECLARE @tipo udtInteger ,
        @cTipo udtName 
        
    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END	
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END
    DECLARE @Recosteado udtLong
                       
    DELETE  dbo.costeo_porcentaje
    WHERE   empresa = @empresa
            AND codigo = @codigo
            AND periodo = @periodo
            AND ayo_operacion = @ao
            AND tipo = @cTipo
            AND serial = @serial
            
            
    SELECT  @Recosteado = SUM(porcentaje)
    FROM    dbo.costeo_porcentaje
    WHERE   empresa = @empresa
            AND codigo = @codigo
            AND periodo = @periodo
            AND ayo_operacion = @ao
            AND tipo = @cTipo
            AND serial > 1  
	
	
	            
                                    
    UPDATE  dbo.costeo_porcentaje
    SET     modificado = 'S' ,
            porcentaje = 100 - @Recosteado
    WHERE   empresa = @empresa
            AND codigo = @codigo
            AND periodo = @periodo
            AND ayo_operacion = @ao
            AND tipo = @cTipo
            AND serial = 1
            
    UPDATE  costeo_porcentaje
    SET     porcentaje = 100
    WHERE   porcentaje IS NULL
            AND serial = 1

                                    
GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Agrega_RecosteoEmpleadosPeriodo')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Agrega_RecosteoEmpleadosPeriodo
GO


CREATE PROCEDURE dbo.Agrega_RecosteoEmpleadosPeriodo
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @periodo udtInteger ,
      @ao udtInteger,
	  @periodoImportar int=0,
	  @aoImportar int=0
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @tipo udtInteger ,
        @cTipo udtName ,
        @cMes udtName
        
    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END 
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END

    DELETE  dbo.costeo_porcentaje
    WHERE   empresa = @empresa
            AND tiponom = @tiponom
            AND periodo = @periodo
            AND ayo_operacion = @ao
            AND tipo = @cTipo							
									
    SET @cMes = CASE WHEN @cTipo = 'MES'
                          AND @periodo = 01
                     THEN 'ENE' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 02
                     THEN 'FEB' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 03
                     THEN 'MAR' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 04
                     THEN 'ABR' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 05
                     THEN 'MAY' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 06
                     THEN 'JUN' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 07
                     THEN 'JUL' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 08
                     THEN 'AGO' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 09
                     THEN 'SEP' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 10
                     THEN 'OCT' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 11
                     THEN 'NOV' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     WHEN @cTipo = 'MES'
                          AND @periodo = 12
                     THEN 'DIC' + SUBSTRING(LTRIM(STR(@ao)), 3, 2)
                     ELSE ''
                END
    
    DECLARE @insertInto udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @fromClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger
    
    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    
    SET @whereClause = 'WHERE k.nomina = ''ORD''  '
    SET @whereClauseUsed = 1
    
    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.empresa = '
                + LTRIM(RTRIM(STR(@empresa)))
                 
        END

    IF @tiponom > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.tiponom = '
                + LTRIM(RTRIM(STR(@tiponom)))
                 
        END
    IF @periodo > 0
        AND @cTipo = 'PER' 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.periodo = '
                + LTRIM(RTRIM(STR(@periodo)))
                 
        END
		
    IF @periodo > 0
        AND @cTipo = 'MES' 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.mes = ''' + @cMes + ''''
                 
        END

    IF @ao > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.ayo_operacion = '
                + LTRIM(RTRIM(STR(@ao)))
                 
        END 
        
    SET @insertInto = 'INSERT INTO dbo.costeo_porcentaje '

    SET @selectClause = 'SELECT	k.empresa,' + 'k.codigo,' + 'l.centro,'
        + 'k.tiponom,'
        + CASE WHEN @cTipo = 'MES'
               THEN ' CASE WHEN SUBSTRING(k.mes,1,3)=''ENE'' THEN 1 WHEN SUBSTRING(k.mes,1,3)=''FEB'' THEN 2 WHEN SUBSTRING(k.mes,1,3)=''MAR'' THEN 3 WHEN SUBSTRING(k.mes,1,3)=''ABR'' THEN 4 WHEN SUBSTRING(k.mes,1,3)=''MAY'' THEN 5 WHEN SUBSTRING(k.mes,1,3)=''JUN'' THEN 6 WHEN SUBSTRING(k.mes,1,3)=''JUL'' THEN 7 WHEN SUBSTRING(k.mes,1,3)=''AGO'' THEN 8 WHEN SUBSTRING(k.mes,1,3)=''SEP'' THEN 9 WHEN SUBSTRING(k.mes,1,3)=''OCT'' THEN 10 WHEN SUBSTRING(k.mes,1,3)=''NOV'' THEN 11 WHEN SUBSTRING(k.mes,1,3)=''DIC'' THEN 12 end'
               ELSE 'k.periodo'
          END + ' AS Periodo,' + 'k.ayo_operacion,'
        + CASE WHEN @cTipo = 'MES' THEN '''MES'''
               ELSE '''PER'''
          END + ' AS Tipo,' + '100 as Porcentaje,'
        + 'CAST(1 AS bigint) AS serial,' + '''N'' AS Modificado '
    SET @fromClause = 'FROM dbo.kardex_anual AS k '
        + 'INNER JOIN dbo.Llaves AS l ON k.empresa = l.empresa AND k.codigo = l.codigo '

    --SET @whereClause = ' WHERE k.nomina = ''ORD'' and k.tiponom =  ' + RTRIM(LTRIM(STR(@tiponom)))
    
    SET @groupByClause = ' GROUP BY k.empresa,' + 'k.codigo,' + 'l.centro,'
        + 'k.tiponom,'
        + CASE WHEN @cTipo = 'MES'
               THEN ' CASE WHEN SUBSTRING(k.mes,1,3)=''ENE'' THEN 1 WHEN SUBSTRING(k.mes,1,3)=''FEB'' THEN 2 WHEN SUBSTRING(k.mes,1,3)=''MAR'' THEN 3 WHEN SUBSTRING(k.mes,1,3)=''ABR'' THEN 4 WHEN SUBSTRING(k.mes,1,3)=''MAY'' THEN 5 WHEN SUBSTRING(k.mes,1,3)=''JUN'' THEN 6 WHEN SUBSTRING(k.mes,1,3)=''JUL'' THEN 7 WHEN SUBSTRING(k.mes,1,3)=''AGO'' THEN 8 WHEN SUBSTRING(k.mes,1,3)=''SEP'' THEN 9 WHEN SUBSTRING(k.mes,1,3)=''OCT'' THEN 10 WHEN SUBSTRING(k.mes,1,3)=''NOV'' THEN 11 WHEN SUBSTRING(k.mes,1,3)=''DIC'' THEN 12 end '
               ELSE 'k.periodo '
          END + ',' + 'k.ayo_operacion '
    SET @orderByClause = 'ORDER BY k.empresa,k.codigo,k.ayo_operacion '


					    
    IF @debug = 0 
        BEGIN 
            EXEC(
            @insertInto + @selectClause + @fromClause + @whereClause + @groupByClause + @orderByClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @insertInto + @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END

	--Set @periodoImportar = iif(@periodoImporta>0,@periodoImportar,
	--						  )
	--Set @periodoImportar = iif(@periodoImporta>0,@periodoImportar)
	
	Declare @Porcentajes as table(empresa int,codigo int,centro varchar(100),tiponom int,periodo int, ayo_operacion int,	tipo varchar(5),porcentaje int,serial int,modificado varchar(1))
	if @periodoImportar<=0
	begin
		insert into @Porcentajes(empresa,codigo,centro,tiponom,periodo,ayo_operacion,tipo,porcentaje,serial,modificado)
		select	a.empresa,
				a.codigo,
				a.centro,
				a.tiponom,
				b.periodo,
				b.ayo_operacion,
				b.tipo,
				b.porcentaje,
				b.serial,
				'S' as modificado
		from dbo.costeo_ultimosRecosteados as a
		inner join dbo.costeo_porcentaje as b on b.empresa=a.empresa and b.codigo=a.codigo 	AND b.periodo = @periodo AND b.ayo_operacion = @ao AND b.tipo = @cTipo
		where	a.empresa = @empresa
		order by a.codigo,a.serial
	end
	else begin
		insert into @Porcentajes(empresa,codigo,centro,tiponom,periodo,ayo_operacion,tipo,porcentaje,serial,modificado)
		select	empresa,codigo,centro,tiponom,periodo,ayo_operacion,tipo,porcentaje,serial,modificado 
		FROM    dbo.costeo_porcentaje AS a
		--inner join dbo.costeo_porcentaje as b on b.empresa=a.empresa and b.codigo=a.codigo and b.serial=a.serial and b.periodo=@periodoImportar and b.ayo_operacion=@aoImportar
		WHERE   a.empresa = @empresa
				AND a.tiponom = @tiponom
				AND a.periodo = @periodoImportar
				AND a.ayo_operacion = @aoImportar
				AND a.tipo = @cTipo
		order by a.codigo,a.serial
	end

	update a set	porcentaje = b.porcentaje ,
					centro = b.centro ,
					modificado = 'S'
	from dbo.costeo_porcentaje as a
	inner join @Porcentajes as b  on b.empresa=a.empresa and b.codigo=a.codigo AND 	a.serial=b.serial--AND b.periodo = @periodo AND b.ayo_operacion = @ao AND b.tipo = @cTipo
	WHERE   a.empresa = @empresa
			AND a.tiponom = @tiponom
			AND a.periodo = @periodo
			AND a.ayo_operacion = @ao
			AND a.tipo = @cTipo
			and a.serial=1
	
	insert into dbo.costeo_porcentaje(empresa,codigo,centro,tiponom,periodo,ayo_operacion,tipo,porcentaje,serial,modificado)
	select	empresa,codigo,centro,tiponom,@periodo,@ao,tipo,porcentaje,serial,modificado 
	FROM    @Porcentajes AS a
	WHERE   a.serial>1
	order by a.codigo,a.serial
		
	--select * 
	--FROM    dbo.costeo_porcentaje AS a
	--inner join dbo.costeo_porcentaje as b on b.empresa=a.empresa and b.codigo=a.codigo and b.serial=a.serial and b.periodo=@periodoImportar and b.ayo_operacion=@aoImportar
	--WHERE   b.serial = 1
	--		AND a.empresa = @empresa
	--		AND a.tiponom = @tiponom
	--		AND a.periodo = @periodo
	--		AND a.ayo_operacion = @ao
	--		AND a.tipo = @cTipo
	--order by a.codigo,a.serial
		    
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RecosteoExtraerPoliza')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RecosteoExtraerPoliza
GO

CREATE PROCEDURE dbo.Obten_RecosteoExtraerPoliza
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @periodo udtInteger ,
      @ao udtInteger ,
      @totales udtInteger
     
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    DECLARE @tipo udtInteger ,
        @cTipo udtName ,
        @cMes udtName
        
    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 0 
        BEGIN
            SET @cTipo = 'MES'
            SET @cMes = CASE WHEN @periodo = 01 THEN 'ENE'
                             WHEN @periodo = 02 THEN 'FEB'
                             WHEN @periodo = 03 THEN 'MAR'
                             WHEN @periodo = 04 THEN 'ABR'
                             WHEN @periodo = 05 THEN 'MAY'
                             WHEN @periodo = 06 THEN 'JUN'
                             WHEN @periodo = 07 THEN 'JUL'
                             WHEN @periodo = 08 THEN 'AGO'
                             WHEN @periodo = 09 THEN 'SEP'
                             WHEN @periodo = 10 THEN 'OCT'
                             WHEN @periodo = 11 THEN 'NOV'
                             WHEN @periodo = 12 THEN 'DIC'
                        END + SUBSTRING(LTRIM(RTRIM(STR(@AO))), 3, 2)
        END 
    ELSE 
        BEGIN
            SET @cMes = ''
            SET @cTipo = 'PER'
        END

    PRINT @cMes

    DECLARE @InsertIntoClause udtStringSize4096
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 1
    SET @whereClause = 'WHERE k.nomina = ''ORD'' '
    SET @orderByClause = ''
    
    
    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.empresa = '
                + LTRIM(RTRIM(STR(@empresa)))
                 
        END
    IF @tiponom > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.tiponom = '
                + LTRIM(RTRIM(STR(@tiponom)))
                 
        END
    IF @ao > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.ayo_operacion = '
                + LTRIM(RTRIM(STR(@ao)))
                 
        END
    IF @periodo > 0
        AND @tipo <> 1 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.periodo = '
                + LTRIM(RTRIM(STR(@periodo)))
                 
        END
    ELSE 
        BEGIN
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.mes = ' + '''' + @cMes + ''''
        END 
	
	--IF OBJECT_ID('@tmp_recosteo_detalle_kardex') IS NOT NULL 
    --BEGIN
        --DROP TABLE @tmp_recosteo_detalle_kardex
    --END
    DECLARE @tmp_recosteo_detalle_kardex_percepcion TABLE
        (
          empresa INT ,
          codigo INT ,
          num_conc INT ,
          concepto VARCHAR(100) ,
          importe NUMERIC(10, 2) ,
          periodo INT ,
          ayo_operacion INT ,
          tipo VARCHAR(3) ,
          centro VARCHAR(50) ,
          modificado VARCHAR(5) ,
          serial INT
        )  
    DECLARE @tmp_recosteo_detalle_kardex_deduccion TABLE
        (
          empresa INT ,
          codigo INT ,
          num_conc INT ,
          concepto VARCHAR(100) ,
          importe NUMERIC(10, 2) ,
          periodo INT ,
          ayo_operacion INT ,
          tipo VARCHAR(3) ,
          centro VARCHAR(50) ,
          modificado VARCHAR(5) ,
          serial INT
        ) 
    DECLARE @tmp_recosteo_detalle_kardex_provision TABLE
        (
          empresa INT ,
          codigo INT ,
          num_conc INT ,
          concepto VARCHAR(100) ,
          importe NUMERIC(10, 2) ,
          periodo INT ,
          ayo_operacion INT ,
          tipo VARCHAR(3) ,
          centro VARCHAR(50) ,
          modificado VARCHAR(5) ,
          serial INT
        )  
    IF OBJECT_ID('dbo.tmp_recosteo_detalle_empleados') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_recosteo_detalle_empleados
        END
    CREATE TABLE dbo.tmp_recosteo_detalle_empleados
        (
          empresa INT ,
          codigo INT ,
          centro VARCHAR(50) ,
          porcentaje INT ,
          serial BIGINT ,
          modificado VARCHAR(5)
        )


    INSERT  INTO DBO.tmp_recosteo_detalle_empleados
            SELECT  a.empresa ,
                    a.codigo ,
                    a.centro ,
                    a.porcentaje ,
                    a.serial ,
                    a.modificado
            FROM    dbo.costeo_porcentaje AS a
            WHERE   a.empresa = @empresa
                    AND a.periodo = @periodo
                    AND a.ayo_operacion = @ao
                    AND a.tipo = @cTipo
	
    DELETE  dbo.costeo_ultimosRecosteados
    WHERE   empresa = @empresa
	
    INSERT  INTO dbo.costeo_ultimosRecosteados
            SELECT  empresa ,
                    codigo ,
                    @tiponom ,
                    centro ,
                    porcentaje ,
                    @cTipo ,
                    serial
            FROM    DBO.tmp_recosteo_detalle_empleados
            WHERE   modificado = 'S'
    --SET @InsertIntoClause = 'INSERT INTO @tmp_recosteo_detalle_kardex  '  
    
    SET @selectClause = 'SELECT  k.empresa, ' + 'k.codigo ,' + 'k.num_conc ,'
        + 'k.concepto ,'
        + 'cast( (sum(k.importe) * (CASE WHEN ( b.porcentaje / 100 ) = 0 THEN 1 ELSE ( b.porcentaje / 100 ) END ) )  as numeric(10,2)) as importe ,'
        + RTRIM(STR(@periodo)) + ' as periodo,'
        + 'k.ayo_operacion as ayo_operacion, ' + '''' + @cTipo + ''' '
        + 'as Tipo,' + 'b.centro as centro, ' + 'b.modificado as modificado,'
        + 'dense_rank() over (partition  by k.codigo,case when k.num_conc <= 99 then 1 when (k.num_conc>=101 and k.num_conc<=199)then 2 when (k.num_conc>=201 and k.num_conc<=299)then 3 else 0 end order by k.num_conc ) as serial '
        
    SET @fromClause = 'FROM dbo.kardex_anual as k '
        + 'INNER JOIN DBO.tmp_recosteo_detalle_empleados as b on k.empresa=b.empresa and k.codigo=b.codigo and b.modificado = ''S'' '
    
    SET @groupByClause = 'GROUP BY k.empresa,k.codigo ,k.num_conc,k.concepto,'
        + 'b.serial,b.porcentaje,k.ayo_operacion,b.centro,b.modificado '
        
    SET @orderByClause = ' ORDER BY k.codigo,k.num_conc '
    
    
    IF @debug = 0 
        BEGIN
            INSERT  INTO @tmp_recosteo_detalle_kardex_percepcion
                    EXEC
                        ( @selectClause + @fromClause + @whereClause
                          + @groupByClause + @orderByClause
                        )
			
        END 
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END
        
        
    SET @fromClause = 'FROM dbo.kardex_anual as k '
        + 'inner JOIN DBO.tmp_recosteo_detalle_empleados as b on k.empresa=b.empresa and k.codigo=b.codigo and b.modificado = ''N'' '
    IF @debug = 0 
        BEGIN
            INSERT  INTO @tmp_recosteo_detalle_kardex_percepcion
                    EXEC
                        ( @selectClause + @fromClause + @whereClause
                          + @groupByClause + @orderByClause
                        )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END
        
        
        
    DECLARE @tmp_polizaRecosteada TABLE
        (
          [empresa] [int] NOT NULL ,
          [codigo] [Bigint] NOT NULL ,
          [nombreEmpleado] [varchar](300) NULL ,
          [afiliacionEmpleado] [varchar](35) NULL ,
          [curpEmpleado] [varchar](30) NULL ,
          [departamentoEmpleado] [Varchar](15) NULL ,
          [nombreDepartamentoEmpleado] [varchar](200) NULL ,
          [cuentaEmpleado] [varchar](30) NULL ,
          [numeroOcupacion] [int] NULL ,
          [actividadEmpleado] [varchar](100) NULL ,
          [fechaAltaEmpleado] [nvarchar](30) NULL ,
          [fechaAntiguedadEmpleado] [varchar](30) NULL ,
          [tipoSalarioEmpleado] [varchar](30) NULL ,
          [jornadaEmpleado] [varchar](30) NULL ,
          [ultimoSueldoEmpleado] [Varchar](35) NULL ,
          [ultimoSBCEmpleado] [Varchar](35) NULL ,
          [claseEmpleado] [varchar](30) NULL ,
          [numeroConceptoPercepcion] [int] NULL ,
          [nombreConceptoPercepcion] [varchar](100) NULL ,
          [importeConceptoPercepcion] [numeric](10, 2) NULL ,
          [numeroConceptoDeduccion] [int] NULL ,
          [nombreConceptoDeduccion] [varchar](100) NULL ,
          [importeConceptoDeduccion] [numeric](10, 2) NULL ,
          [numeroConceptoProvision] [int] NULL ,
          [nombreConceptoProvision] [varchar](100) NULL ,
          [importeConceptoProvision] [numeric](10, 2) NULL ,
          [totalPercepcionesEmpleado] [numeric](38, 2) NULL ,
          [totalDeduccionesEmpleado] [numeric](38, 2) NULL ,
          [totalprovisionesEmpleado] [numeric](38, 2) NULL ,
          [netoPagarEmpleado] [numeric](38, 2) NULL ,
          [serial] [Bigint] NOT NULL ,
          [grupo] [varchar](100) NOT NULL ,
          [nombreGrupo] [varchar](200) NULL ,
          [modificado] [varchar](2) NULL ,
          [periodo] [varchar](250) NULL ,
          PRIMARY KEY NONCLUSTERED ( empresa, codigo, grupo, serial )
        )
    DECLARE @totalRows AS BIGINT ,
        @counter INT ,
        @counter2 INT
    SET @counter = 1 
    SET @counter2 = 2
			
    
    --INSERT  INTO @tmp_polizaRecosteada
    DECLARE @tmp_empleados TABLE
        (
          empresa INT ,
          codigo INT ,
          centro VARCHAR(15) ,
          serial INT IDENTITY
        )
        
    INSERT  INTO @tmp_empleados
            ( empresa ,
              codigo ,
              centro
            )
            SELECT  empresa ,
                    codigo ,
                    centro
            FROM    dbo.tmp_recosteo_detalle_empleados
            GROUP BY empresa ,
                    codigo ,
                    centro
    
    SET @totalRows = @@ROWCOUNT
    DECLARE @i udtInteger
    DECLARE @registros TABLE
        (
          registro INT ,
          empresa INT
        )
    SET @i = 1
    WHILE @i <= 30 
        BEGIN 
            INSERT  INTO @registros
                    ( registro, empresa )
            VALUES  ( @i, @empresa )
            SET @i = @i + 1		
    
        END
    
    
    
    
    IF @totales = 1 
        BEGIN
            INSERT  INTO @tmp_polizaRecosteada
                    ( empresa ,
                      codigo ,
                      departamentoEmpleado ,
                      serial ,
                      grupo
                    )
                    SELECT  @empresa AS empresa ,
                            a.codigo ,
                            a.centro ,
                            b.registro ,
                            a.centro
                    FROM    dbo.tmp_recosteo_detalle_empleados AS a ,
                            @registros AS b
                    ORDER BY a.centro ,
                            a.codigo ,
                            a.serial    
			
            UPDATE  a
            SET     nombreEmpleado = CAST(e.codigo AS VARCHAR(10)) + ' '
                    + RTRIM(e.ap_paterno) + ' ' + RTRIM(e.ap_materno) + ' '
                    + RTRIM(e.nombre) ,
                    afiliacionEmpleado = RTRIM(e.afiliacion) + '-'
                    + RTRIM(e.digvera) ,
                    curpEmpleado = RTRIM(e.curp) ,
                    nombreDepartamentoEmpleado = d.nomdepto ,
                    cuentaEmpleado = 'Cta. ' + RTRIM(e.cta_bco_no) ,
                    numeroOcupacion = t.ocupacion ,
                    actividadEmpleado = t.actividad ,
                    fechaAltaEmpleado = 'Fecha de Ingreso: '
                    + CONVERT(NVARCHAR(20), e.fchalta, 103) ,
                    fechaAntiguedadEmpleado = CONVERT(NVARCHAR(20), e.fchantigua, 103) ,
                    tipoSalarioEmpleado = 'Tipo de salario: '
                    + CASE WHEN e.tiposal = 0 THEN '0. Fijo'
                           WHEN e.tiposal = 1 THEN '1. Variable'
                           WHEN e.tiposal = 2 THEN '2. Mixto'
                      END ,
                    jornadaEmpleado = 'Jornada: '
                    + CASE WHEN e.jornada = 0 THEN '0. Normal'
                           WHEN e.jornada = 1 THEN '1. Reducida'
                      END ,
                    ultimoSueldoEmpleado = 'Ultimo: Sdo Diario $'
                    + CAST(e.sueldo AS VARCHAR(30)) ,
                    ultimoSBCEmpleado = 'S.B.C. IMSS $'
                    + CAST(e.saldiaint AS VARCHAR(30)) ,
                    claseEmpleado = 'Classe: ' + RTRIM(l.clase) ,
                    modificado = 'N' ,
                    nombreGrupo = RTRIM(d.nomdepto) ,
                    periodo = CASE WHEN @cTipo = 'PER' THEN 'Periodo: '
                                   WHEN @cTipo = 'MES' THEN 'Mes: '
                              END + LTRIM(STR(@periodo)) + ' '
                    + LTRIM(STR(@ao))
            FROM    @tmp_polizaRecosteada AS a
                    INNER JOIN dbo.empleados AS e ON a.empresa = e.empresa
                                                     AND a.codigo = e.codigo
                    INNER JOIN dbo.llaves AS l ON e.empresa = l.empresa
                                                  AND e.codigo = l.codigo
                    INNER JOIN dbo.tabulador AS t ON l.empresa = t.empresa
                                                     AND l.ocupacion = t.ocupacion
                    INNER JOIN dbo.centros AS d ON a.empresa = d.empresa
                                                   AND a.departamentoEmpleado = d.centro
            
            UPDATE  @tmp_polizaRecosteada
            SET     numeroConceptoPercepcion = b.num_conc ,
                    nombreConceptoPercepcion = b.concepto ,
                    importeConceptoPercepcion = b.importe ,
                    totalPercepcionesEmpleado = ( SELECT    SUM(importe)
                                                  FROM      @tmp_recosteo_detalle_kardex_percepcion
                                                  WHERE     empresa = a.empresa
                                                            AND codigo = a.codigo
                                                            AND centro = a.grupo
                                                            AND ( num_conc >= 1
                                                              AND num_conc <= 99
                                                              )
                                                ) ,
                    modificado = 'S'
            FROM    @tmp_polizaRecosteada AS a
                    INNER JOIN @tmp_recosteo_detalle_kardex_percepcion AS b ON a.empresa = b.empresa
                                                              AND a.codigo = b.codigo
                                                              AND a.grupo = b.centro
                                                              AND a.serial = b.serial
                                                              AND ( b.num_conc >= 1
                                                              AND b.num_conc <= 99
                                                              )
	
            UPDATE  @tmp_polizaRecosteada
            SET     numeroConceptoDeduccion = b.num_conc ,
                    nombreConceptoDeduccion = b.concepto ,
                    importeConceptoDeduccion = b.importe ,
                    totalDeduccionesEmpleado = ( SELECT SUM(importe)
                                                 FROM   @tmp_recosteo_detalle_kardex_percepcion
                                                 WHERE  empresa = a.empresa
                                                        AND codigo = a.codigo
                                                        AND centro = a.grupo
                                                        AND ( num_conc >= 101
                                                              AND num_conc <= 199
                                                            )
                                               ) ,
                    netoPagarEmpleado = ( SELECT    SUM(importe)
                                          FROM      @tmp_recosteo_detalle_kardex_percepcion
                                          WHERE     empresa = a.empresa
                                                    AND codigo = a.codigo
                                                    AND centro = a.grupo
                                                    AND ( num_conc >= 1
                                                          AND num_conc <= 99
                                                        )
                                        )
                    - ( SELECT  SUM(importe)
                        FROM    @tmp_recosteo_detalle_kardex_percepcion
                        WHERE   empresa = a.empresa
                                AND codigo = a.codigo
                                AND centro = a.grupo
                                AND ( num_conc >= 101
                                      AND num_conc <= 199
                                    )
                      ) ,
                    modificado = 'S'
            FROM    @tmp_polizaRecosteada AS a
                    INNER JOIN @tmp_recosteo_detalle_kardex_percepcion AS b ON a.empresa = b.empresa
                                                              AND a.codigo = b.codigo
                                                              AND a.grupo = b.centro
                                                              AND a.serial = b.serial
                                                              AND ( b.num_conc >= 101
                                                              AND b.num_conc <= 199
                                                              )
	
            UPDATE  @tmp_polizaRecosteada
            SET     numeroConceptoProvision = b.num_conc ,
                    nombreConceptoProvision = b.concepto ,
                    importeConceptoProvision = b.importe ,
                    totalProvisionesEmpleado = ( SELECT SUM(importe)
                                                 FROM   @tmp_recosteo_detalle_kardex_provision
                                                 WHERE  empresa = a.empresa
                                                        AND codigo = a.codigo
                                                        AND centro = a.grupo
                                                        AND ( num_conc >= 201
                                                              AND num_conc <= 299
                                                            )
                                               ) ,
                    modificado = 'S'
            FROM    @tmp_polizaRecosteada AS a
                    INNER JOIN @tmp_recosteo_detalle_kardex_percepcion AS b ON a.empresa = b.empresa
                                                              AND a.codigo = b.codigo
                                                              AND a.grupo = b.centro
                                                              AND a.serial = b.serial
                                                              AND ( b.num_conc >= 201
                                                              AND b.num_conc <= 299
                                                              )
	
	
            DELETE  @tmp_polizaRecosteada
            WHERE   modificado = 'N'
        END
        

    DECLARE @tmp_centros TABLE
        (
          empresa INT ,
          codigo BIGINT ,
          centro VARCHAR(15) ,
          serial BIGINT IDENTITY
        )
        
    INSERT  INTO @tmp_centros
            ( empresa ,
              codigo ,
              centro
            )
            SELECT  empresa ,
                    999999999999 ,
                    centro
            FROM    dbo.tmp_recosteo_detalle_empleados
            GROUP BY empresa ,
                    centro
    
    SET @totalRows = @@ROWCOUNT
    PRINT @totalRows
    DECLARE @registros_centros TABLE
        (
          registro INT ,
          empresa INT
        )
    SET @i = 1
    WHILE @i <= 30 
        BEGIN 
            INSERT  INTO @registros_centros
                    ( registro, empresa )
            VALUES  ( @i, @empresa )
            SET @i = @i + 1		
		
        END
    
    INSERT  INTO @tmp_polizaRecosteada
            ( empresa ,
              codigo ,
              departamentoEmpleado ,
              serial ,
              grupo
            )
            SELECT  @empresa AS empresa ,
                    999999999999 ,
                    '' ,
                    registro ,
                    centro
            FROM    dbo.tmp_recosteo_detalle_empleados ,
                    @registros
            GROUP BY centro ,
                    registro--,serial
            ORDER BY centro ,
                    registro
	
			--UPDATE  a 
    DECLARE @tmp_detalle_centros_per TABLE
        (
          empresa INT ,
          centro VARCHAR(15) ,
          numeroConceptoPercepcion INT ,
          nombreConceptoPercepcion VARCHAR(40) ,
          importeConceptoPercepcion NUMERIC(10, 2) ,
          totalPercepcionesEmpleado NUMERIC(10, 2) ,
          modificado VARCHAR(2) ,
          serial BIGINT IDENTITY
        )
    INSERT  INTO @tmp_detalle_centros_per
            ( empresa ,
              centro ,
              numeroConceptoPercepcion ,
              nombreConceptoPercepcion ,
              importeConceptoPercepcion ,
              totalPercepcionesEmpleado ,
              modificado
            )
            SELECT  b.empresa ,
                    b.centro ,
                    numeroConceptoPercepcion = b.num_conc ,
                    nombreConceptoPercepcion = b.concepto ,
                    importeConceptoPercepcion = SUM(b.importe) ,
                    totalPercepcionesEmpleado = ( SELECT    SUM(importe)
                                                  FROM      @tmp_recosteo_detalle_kardex_percepcion
                                                  WHERE     empresa = b.empresa
                                                            AND centro = b.centro
                                                            AND ( num_conc >= 1
                                                              AND num_conc <= 99
                                                              )
                                                ) ,
                    'S'
            FROM    @tmp_recosteo_detalle_kardex_percepcion AS b
            WHERE   ( b.num_conc >= 1
                      AND b.num_conc <= 99
                    )
            GROUP BY b.empresa ,
                    b.centro ,
                    b.num_conc ,
                    b.concepto 
	
	
    UPDATE  @tmp_polizaRecosteada
    SET     numeroConceptoPercepcion = b.numeroConceptoPercepcion ,
            nombreConceptoPercepcion = b.nombreConceptoPercepcion ,
            importeConceptoPercepcion = b.importeConceptoPercepcion ,
            totalPercepcionesEmpleado = b.totalPercepcionesEmpleado ,
            netoPagarEmpleado = 0 ,
            modificado = b.modificado
    FROM    @tmp_polizaRecosteada AS a
            INNER JOIN @tmp_detalle_centros_per AS b ON a.empresa = b.empresa
                                                        AND a.grupo = b.centro
                                                        AND a.serial = b.serial
    WHERE   a.codigo = 999999999999
	
	
            
            
    DECLARE @tmp_detalle_centros_ded TABLE
        (
          empresa INT ,
          centro VARCHAR(15) ,
          numeroConceptoDeduccion INT ,
          nombreConceptoDeduccion VARCHAR(40) ,
          importeConceptoDeduccion NUMERIC(10, 2) ,
          totalDeduccionesEmpleado NUMERIC(10, 2) ,
          modificado VARCHAR(2) ,
          serial BIGINT IDENTITY
        )
    INSERT  INTO @tmp_detalle_centros_ded
            ( empresa ,
              centro ,
              numeroConceptoDeduccion ,
              nombreConceptoDeduccion ,
              importeConceptoDeduccion ,
              totalDeduccionesEmpleado ,
              modificado
            )
            SELECT  b.empresa ,
                    b.centro ,
                    numeroConceptoDeduccion = b.num_conc ,
                    nombreConceptoDeduccion = b.concepto ,
                    importeConceptoDeduccion = SUM(b.importe) ,
                    totalDeduccionesEmpleado = ( SELECT SUM(importe)
                                                 FROM   @tmp_recosteo_detalle_kardex_percepcion
                                                 WHERE  empresa = b.empresa
                                                        AND centro = b.centro
                                                        AND ( num_conc >= 101
                                                              AND num_conc <= 199
                                                            )
                                               ) ,
                    'S'
            FROM    @tmp_recosteo_detalle_kardex_percepcion AS b
            WHERE   ( b.num_conc >= 101
                      AND b.num_conc <= 199
                    )
            GROUP BY b.empresa ,
                    b.centro ,
                    b.num_conc ,
                    b.concepto 
	
	
    UPDATE  @tmp_polizaRecosteada
    SET     numeroConceptoDeduccion = b.numeroConceptoDeduccion ,
            nombreConceptoDeduccion = b.nombreConceptoDeduccion ,
            importeConceptoDeduccion = b.importeConceptoDeduccion ,
            totalDeduccionesEmpleado = b.totalDeduccionesEmpleado ,
            netoPagarEmpleado = 0 ,
            modificado = b.modificado
    FROM    @tmp_polizaRecosteada AS a
            INNER JOIN @tmp_detalle_centros_ded AS b ON a.empresa = b.empresa
                                                        AND a.grupo = b.centro
                                                        AND a.serial = b.serial
    WHERE   a.codigo = 999999999999
                                                              
                                                              
                                                              
            
    DECLARE @tmp_detalle_centros_prov TABLE
        (
          empresa INT ,
          centro VARCHAR(15) ,
          numeroConceptoProvision INT ,
          nombreConceptoProvision VARCHAR(100) ,
          importeConceptoProvision NUMERIC(10, 2) ,
          totalProvisionesEmpleado NUMERIC(10, 2) ,
          modificado VARCHAR(2) ,
          serial BIGINT IDENTITY
        )
    INSERT  INTO @tmp_detalle_centros_prov
            ( empresa ,
              centro ,
              numeroConceptoProvision ,
              nombreConceptoProvision ,
              importeConceptoProvision ,
              totalProvisionesEmpleado ,
              modificado
            )
            SELECT  b.empresa ,
                    b.centro ,
                    numeroConceptoProvision = b.num_conc ,
                    nombreConceptoProvision = b.concepto ,
                    importeConceptoProvision = SUM(b.importe) ,
                    totalProvisionesEmpleado = ( SELECT SUM(importe)
                                                 FROM   @tmp_recosteo_detalle_kardex_percepcion
                                                 WHERE  empresa = b.empresa
                                                        AND centro = b.centro
                                                        AND ( num_conc >= 201
                                                              AND num_conc <= 299
                                                            )
                                               ) ,
                    'S'
            FROM    @tmp_recosteo_detalle_kardex_percepcion AS b
            WHERE   ( b.num_conc >= 201
                      AND b.num_conc <= 299
                    )
            GROUP BY b.empresa ,
                    b.centro ,
                    b.num_conc ,
                    b.concepto 
	
	
    UPDATE  @tmp_polizaRecosteada
    SET     numeroConceptoProvision = b.numeroConceptoProvision ,
            nombreConceptoProvision = b.nombreConceptoProvision ,
            importeConceptoProvision = b.importeConceptoProvision ,
            totalProvisionesEmpleado = b.totalProvisionesEmpleado ,
            netoPagarEmpleado = 0 ,
            modificado = b.modificado
    FROM    @tmp_polizaRecosteada AS a
            INNER JOIN @tmp_detalle_centros_prov AS b ON a.empresa = b.empresa
                                                         AND a.grupo = b.centro
                                                         AND a.serial = b.serial
    WHERE   a.codigo = 999999999999
	
	
    DELETE  @tmp_polizaRecosteada
    WHERE   modificado = 'N'
            OR modificado IS NULL	
    
    UPDATE  a
    SET     nombregrupo = c.nomdepto ,
            ultimoSueldoEmpleado = '' ,
            ultimoSBCEmpleado = '' ,
            cuentaEmpleado = '' ,
            nombreEmpleado = LTRIM(c.centro) + RTRIM(c.nomdepto) ,
            afiliacionEmpleado = '' ,
            curpEmpleado = '' ,
            numeroOcupacion = 0 ,
            actividadEmpleado = '' ,
            fechaAltaEmpleado = '' ,
            fechaAntiguedadEmpleado = '' ,
            tipoSalarioEmpleado = '' ,
            jornadaEmpleado = '' ,
            claseEmpleado = '' ,
            periodo = ''
    FROM    @tmp_polizaRecosteada AS a
            INNER JOIN dbo.centros AS c ON a.empresa = c.empresa
                                           AND c.centro = a.grupo
    WHERE   A.codigo = 999999999999 
    
    
    
    
    SELECT  *
    FROM    @tmp_polizaRecosteada
    ORDER BY grupo ,
            codigo ,
            serial
    
    IF OBJECT_ID('dbo.tmp_recosteo_detalle_empleados') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_recosteo_detalle_empleados
        END
	
GO




IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RecosteoTiposnomPeriodosImprimir')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RecosteoTiposnomPeriodosImprimir
GO


CREATE PROCEDURE dbo.Obten_RecosteoTiposnomPeriodosImprimir ( @empresa udtInteger )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @tipo udtInteger ,
        @cTipo udtName ,
        @cMes udtName
        
    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END 
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END
        
    SELECT  '0' + LTRIM(STR(tiponom)) + ' '
            + CASE WHEN tiponom = 1 THEN 'SEMANAL'
                   WHEN tiponom = 2 THEN 'DECENAL'
                   WHEN tiponom = 3 THEN 'CATORCENAL'
                   WHEN tiponom = 4 THEN 'QUINCENAL'
                   WHEN tiponom = 5 THEN 'MENSUAL'
                   WHEN tiponom = 6 THEN 'ESPECIAL'
              END AS 'Tipo de Nomina'
    FROM    dbo.costeo_porcentaje
    WHERE   empresa = @empresa
    GROUP BY tiponom
	
	
	
	
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RecosteoPeriodosImprimir')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RecosteoPeriodosImprimir
GO


CREATE PROCEDURE dbo.Obten_RecosteoPeriodosImprimir
    (
      @empresa udtInteger ,
      @tiponom udtInteger
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @tipo udtInteger ,
        @cTipo udtName ,
        @cMes udtName
        
    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END 
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END
        
    IF @tipo = 1 
        BEGIN
            SELECT  CASE WHEN K.periodo = 01 THEN 'ENE'
                         WHEN K.periodo = 02 THEN 'FEB'
                         WHEN K.periodo = 03 THEN 'MAR'
                         WHEN K.periodo = 04 THEN 'ABR'
                         WHEN K.periodo = 05 THEN 'MAY'
                         WHEN K.periodo = 06 THEN 'JUN'
                         WHEN K.periodo = 07 THEN 'JUL'
                         WHEN K.periodo = 08 THEN 'AGO'
                         WHEN K.periodo = 09 THEN 'SEP'
                         WHEN K.periodo = 10 THEN 'OCT'
                         WHEN K.periodo = 11 THEN 'NOV'
                         WHEN K.periodo = 12 THEN 'DIC'
                    END + ' ' + LTRIM(STR(k.ayo_operacion)) AS Periodo
            FROM    dbo.costeo_porcentaje AS k
            WHERE   k.empresa = @empresa
                    AND k.tiponom = @tiponom
            GROUP BY k.ayo_operacion ,
                    K.periodo
            ORDER BY k.ayo_operacion DESC ,
                    k.periodo
 
        END 
			
    ELSE 
        BEGIN
            SELECT  REPLICATE('0', 3 - LEN(LTRIM(STR(k.periodo))))
                    + LTRIM(STR(k.periodo)) + ' ' + LTRIM(STR(k.ayo_operacion)) AS Periodo
            FROM    dbo.costeo_porcentaje AS k
            WHERE   k.empresa = @empresa
                    AND k.tiponom = @tiponom
            GROUP BY k.periodo ,
                    k.ayo_operacion
            ORDER BY k.ayo_operacion DESC ,
                    k.periodo DESC 
        END

	
	
	
	
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RecosteoExtraerNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RecosteoExtraerNomina
GO

CREATE PROCEDURE dbo.Obten_RecosteoExtraerNomina
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @periodo udtInteger ,
      @ao udtInteger,
      @tipoReporte udtInteger
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    DECLARE @tipo udtInteger ,
        @cTipo udtName ,
        @cMes udtName
        
    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
            SET @cMes = CASE WHEN @periodo = 01 THEN 'ENE'
                             WHEN @periodo = 02 THEN 'FEB'
                             WHEN @periodo = 03 THEN 'MAR'
                             WHEN @periodo = 04 THEN 'ABR'
                             WHEN @periodo = 05 THEN 'MAY'
                             WHEN @periodo = 06 THEN 'JUN'
                             WHEN @periodo = 07 THEN 'JUL'
                             WHEN @periodo = 08 THEN 'AGO'
                             WHEN @periodo = 09 THEN 'SEP'
                             WHEN @periodo = 10 THEN 'OCT'
                             WHEN @periodo = 11 THEN 'NOV'
                             WHEN @periodo = 12 THEN 'DIC'
                        END + SUBSTRING(LTRIM(RTRIM(STR(@AO))), 3, 2)
        END 
    ELSE 
        BEGIN
            SET @cMes = ''
            SET @cTipo = 'PER'
        END

    PRINT @cMes
    PRINT @cTipo

    DECLARE @InsertIntoClause udtStringSize4096
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 1
    SET @whereClause = 'WHERE k.nomina = ''ORD'''
    SET @orderByClause = ''
    
    
    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.empresa = '
                + LTRIM(RTRIM(STR(@empresa)))
                 
        END
    IF @tiponom > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.tiponom = '
                + LTRIM(RTRIM(STR(@tiponom)))
                 
        END
    IF @ao > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.ayo_operacion = '
                + LTRIM(RTRIM(STR(@ao)))
                 
        END
    IF @periodo > 0
        AND @tipo <> 1 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.periodo = '
                + LTRIM(RTRIM(STR(@periodo)))
                 
        END
    ELSE 
        BEGIN
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.mes = ' + '''' + @cMes + ''''
        END 
	
    IF OBJECT_ID('dbo.tmp_recosteo_detalle_empleados') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_recosteo_detalle_empleados
        END
        
    DECLARE @tmp_recosteo_detalle_kardex TABLE
        (
          empresa INT ,
          codigo BIGINT ,
          num_conc INT ,
          concepto VARCHAR(45) ,
          importe NUMERIC(10, 2) ,
          periodo INT ,
          ayo_operacion INT ,
          tipo VARCHAR(3) ,
          centro VARCHAR(15) ,
          modificado VARCHAR(1) ,
          serial INT
        )  
        
    CREATE TABLE dbo.tmp_recosteo_detalle_empleados
        (
          empresa INT ,
          codigo INT ,
          centro VARCHAR(15) ,
          porcentaje INT ,
          serial BIGINT ,
          modificado VARCHAR(1)
        )


    INSERT  INTO DBO.tmp_recosteo_detalle_empleados
            SELECT  a.empresa ,
                    a.codigo ,
                    a.centro ,
                    a.porcentaje ,
                    a.serial ,
                    a.modificado
            FROM    dbo.costeo_porcentaje AS a
            WHERE   a.empresa = @empresa
                    AND a.periodo = @periodo
                    AND a.ayo_operacion = @ao
                    AND a.tipo = @cTipo
	
    DELETE  dbo.costeo_ultimosRecosteados
    WHERE   empresa = @empresa
	
	--SELECT * FROM DBO.tmp_recosteo_detalle_empleados ORDER BY codigo
	
    INSERT  INTO dbo.costeo_ultimosRecosteados
            SELECT  empresa ,
                    codigo ,
                    @tiponom ,
                    centro ,
                    porcentaje ,
                    @cTipo ,
                    serial
            FROM    DBO.tmp_recosteo_detalle_empleados
            WHERE   modificado = 'S'
    --SET @InsertIntoClause = 'INSERT INTO @tmp_recosteo_detalle_kardex  '  
    
    SET @selectClause = 'SELECT  k.empresa, ' + 'k.codigo ,' + 'k.num_conc ,'
        + 'k.concepto ,'
        + 'cast( (sum(k.importe) * ( convert(numeric(10,2),convert(numeric(10,2),b.porcentaje) / 100) ) )  as numeric(10,2)) as importe ,'
        + RTRIM(STR(@periodo)) + ' as periodo,'
        + 'k.ayo_operacion as ayo_operacion, ' + '''' + @cTipo + ''' '
        + 'as Tipo,' + 'b.centro as centro, ' + 'b.modificado as modificado,'
        + 'dense_rank() over (partition  by k.codigo,case when k.num_conc <= 99 then 1 when (k.num_conc>=101 and k.num_conc<=199)then 2 when (k.num_conc>=201 and k.num_conc<=299)then 3 else 0 end order by k.num_conc ) as serial '
        
    SET @fromClause = 'FROM dbo.kardex_anual as k '
        + 'INNER JOIN DBO.tmp_recosteo_detalle_empleados as b on k.empresa=b.empresa and k.codigo=b.codigo and b.modificado = ''S'' '
    
    SET @groupByClause = 'GROUP BY k.empresa,k.codigo ,k.num_conc,k.concepto,'
        + 'b.serial,b.porcentaje,k.ayo_operacion,b.centro,b.modificado '
        
    SET @orderByClause = ' ORDER BY k.codigo,k.num_conc '
    
    
    IF @debug = 0 
        BEGIN
            INSERT  INTO @tmp_recosteo_detalle_kardex
                    EXEC
                        ( @selectClause + @fromClause + @whereClause
                          + @groupByClause + @orderByClause
                        )
			
        END 
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END
    SET @fromClause = 'FROM dbo.kardex_anual as k '
        + 'inner JOIN DBO.tmp_recosteo_detalle_empleados as b on k.empresa=b.empresa and k.codigo=b.codigo and b.modificado = ''N'' '
    IF @debug = 0 
        BEGIN
            INSERT  INTO @tmp_recosteo_detalle_kardex
                    EXEC
                        ( @selectClause + @fromClause + @whereClause
                          + @groupByClause + @orderByClause
                        )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END
    
    INSERT  INTO @tmp_recosteo_detalle_kardex
            SELECT  empresa ,
                    codigo ,
                    1199 ,
                    'Total Percep.' ,
                    SUM(importe) ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    centro ,
                    modificado ,
                    MAX(serial) + 1
            FROM    @tmp_recosteo_detalle_kardex
            WHERE   ( ( num_conc >= 1
                        AND num_conc <= 99
                      )
                      OR ( num_conc >= 501
                           AND num_conc <= 599
                         )
                      OR ( num_conc >= 1100
                           AND num_conc <= 1199
                         )
                    )
            GROUP BY empresa ,
                    codigo ,
                    centro ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    centro ,
                    modificado
    
    INSERT  INTO @tmp_recosteo_detalle_kardex
            SELECT  empresa ,
                    codigo ,
                    1098 ,
                    'Total Deduc.' ,
                    SUM(importe) ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    centro ,
                    modificado ,
                    MAX(serial) + 1
            FROM    @tmp_recosteo_detalle_kardex
            WHERE   ( ( num_conc >= 101
                        AND num_conc <= 199
                      )
                      OR ( num_conc >= 601
                           AND num_conc <= 699
                         )
                      OR ( num_conc >= 1001
                           AND num_conc <= 1099
                         )
                    )
            GROUP BY empresa ,
                    codigo ,
                    centro ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    centro ,
                    modificado
    
    INSERT  INTO @tmp_recosteo_detalle_kardex
            SELECT  empresa ,
                    codigo ,
                    299 ,
                    'Total Prov.' ,
                    SUM(importe) ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    centro ,
                    modificado ,
                    MAX(serial) + 1
            FROM    @tmp_recosteo_detalle_kardex
            WHERE   num_conc >= 201
                    AND num_conc <= 299
            GROUP BY empresa ,
                    codigo ,
                    centro ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    centro ,
                    modificado
    
    INSERT  INTO @tmp_recosteo_detalle_kardex
            SELECT  empresa ,
                    codigo ,
                    1099 ,
                    'Neto' ,
                    SUM(CASE WHEN num_conc = 1199 THEN importe
                             ELSE 0
                        END) - SUM(CASE WHEN num_conc = 1098 THEN importe
                                        ELSE 0
                                   END) ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    centro ,
                    modificado ,
                    MAX(serial) + 1
            FROM    @tmp_recosteo_detalle_kardex
            WHERE   num_conc IN ( 1199, 1098 )
            GROUP BY empresa ,
                    codigo ,
                    centro ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    centro ,
                    modificado
    
    INSERT  INTO @tmp_recosteo_detalle_kardex
            SELECT  empresa ,
                    77777777777 AS codigo ,
                    num_conc ,
                    concepto ,
                    SUM(importe) AS importe ,
                    periodo ,
                    ayo_operacion ,
                    tipo ,
                    '99999999999999' AS centro ,
                    'N' ,
                    MAX(serial) + 1
            FROM    @tmp_recosteo_detalle_kardex
            GROUP BY empresa ,
                    num_conc ,
                    concepto ,
                    periodo ,
                    ayo_operacion ,
                    tipo
    
    IF OBJECT_ID('dbo.tmp_concs') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_concs
        END
    
    
    DECLARE @totalRows udtLong
    DECLARE @centrosString udtStringSize8000
    DECLARE @centrosString2 udtStringSize8000
    DECLARE @namesString udtStringSize8000
    DECLARE @counter udtInteger

    SET @counter = 1 
    SET @centrosString = ''
    SET @namesString = ''
    
    CREATE TABLE dbo.tmp_concs
        (
          num_conc INT ,
          concepto VARCHAR(40) ,
          serial BIGINT
        )
    INSERT  INTO dbo.tmp_concs
            ( num_conc ,
              concepto ,
              serial 
            )
            SELECT  num_conc ,
                    MAX(concepto) ,
                    dense_rank() OVER ( PARTITION  BY 0 ORDER BY CASE
                                                              WHEN ( ( num_conc >= 1
                                                              AND num_conc <= 99
                                                              )
                                                              OR ( num_conc >= 501
                                                              AND num_conc <= 599
                                                              )
                                                              OR ( num_conc >= 1100
                                                              AND num_conc <= 1199
                                                              )
                                                              ) THEN 1
                                                              WHEN ( ( num_conc >= 101
                                                              AND num_conc <= 200
                                                              )
                                                              OR ( num_conc >= 601
                                                              AND num_conc <= 699
                                                              )
                                                              OR ( num_conc >= 1001
                                                              AND num_conc <= 1099
                                                              )
                                                              ) THEN 2
                                                              WHEN ( (num_conc >= 201
                                                              AND num_conc <= 299)
                                                              ) THEN 3
                                                              END, num_conc ) serial
            FROM    @tmp_recosteo_detalle_kardex
            GROUP BY num_conc
            ORDER BY CASE WHEN ( ( num_conc >= 1
                                   AND num_conc <= 99
                                 )
                                 OR ( num_conc >= 501
                                      AND num_conc <= 599
                                    )
                                 OR ( num_conc >= 1100
                                      AND num_conc <= 1199
                                    )
                               ) THEN 1
                          WHEN ( ( num_conc >= 101
                                   AND num_conc <= 199
                                 )
                                 OR ( num_conc >= 601
                                      AND num_conc <= 699
                                    )
                                 OR ( num_conc >= 1001
                                      AND num_conc <= 1099
                                    )
                               ) THEN 2
                          WHEN ( (num_conc >= 201
                                 AND num_conc <= 299)
                               ) THEN 3
                     END ,
                    num_conc
            
    SET @totalRows = ISNULL(( SELECT    MAX(serial)
                              FROM      dbo.tmp_concs
                            ), 0)
	
    SET @counter = 1
    WHILE @counter <= @totalRows 
        BEGIN
            SET @centrosString = @centrosString + ',['
                + ( SELECT  LTRIM(STR(num_conc))
                    FROM    dbo.tmp_concs
                    WHERE   serial = @counter
                  ) + ']numeric(10,2) null '
            SET @namesString = @namesString
                + ',case when  (a.codigo = 88888888888 or a.codigo = 0) then null else isnull(a.['
                + ( SELECT  LTRIM(STR(num_conc))
                    FROM    dbo.tmp_concs
                    WHERE   serial = @counter
                  ) + '],0) end  AS ' + ''''
                + ( SELECT  CASE WHEN num_conc = 1199
                                      OR num_conc = 1098
                                      OR num_conc = 1099
                                      OR num_conc = 299 THEN ''
                                 ELSE LTRIM(STR(num_conc))
                            END + ' ' + concepto
                    FROM    dbo.tmp_concs
                    WHERE   serial = @counter
                  ) + ''''
            SET @counter = @counter + 1 
        END
        
    IF OBJECT_ID('dbo.tmp_detalleResumido') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_detalleResumido
        END
    IF OBJECT_ID('dbo.tmp_detalle2') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_detalle2
        END
        
    SELECT  codigo ,
            num_conc ,
            centro ,
            concepto ,
            importe
    INTO    dbo.tmp_detalle2
    FROM    @tmp_recosteo_detalle_kardex
        
        
    SET @centrosString2 = SUBSTRING(@centrosString, 2, LEN(@centrosString))
		
    EXEC('Create Table dbo.tmp_detalleResumido (empresa int,codigo bigint not null,nombre varchar(50) not null,centro varchar(15) not null' + @centrosString + '  PRIMARY KEY NONCLUSTERED (centro,codigo) )' )
	
    
   IF @tipoReporte = 0 BEGIN
		INSERT  INTO dbo.tmp_detalleResumido
            ( empresa ,
              codigo ,
              nombre ,
              centro
            )
        SELECT  empresa ,
                codigo ,
                nombre ,
                centro
        FROM    ( (
		SELECT  a.empresa AS 'Empresa' ,
				a.codigo AS 'Codigo' ,
				RTRIM(b.ap_paterno) + ' ' + RTRIM(b.ap_materno) + ' '
				+ RTRIM(b.nombre) AS 'Nombre' ,
				a.centro AS 'Centro'
		FROM    @tmp_recosteo_detalle_kardex AS a
				INNER JOIN dbo.centros AS c ON a.empresa = c.empresa
											   AND a.centro = c.centro
				INNER JOIN dbo.empleados AS b ON a.empresa = b.empresa
												 AND a.codigo = b.codigo
		GROUP BY a.empresa ,
				a.codigo ,
				RTRIM(b.ap_paterno) + ' ' + RTRIM(b.ap_materno) + ' '
				+ RTRIM(b.nombre) ,
				a.centro 
		)
						  UNION
						  ( SELECT  a.empresa AS 'Empresa' ,
									0 AS 'Codigo' ,
									c.nomdepto AS 'Nombre' ,
									a.centro AS 'Centro'
							FROM    @tmp_recosteo_detalle_kardex AS a
									INNER JOIN dbo.centros AS c ON a.empresa = c.empresa
																  AND a.centro = c.centro
							GROUP BY a.empresa ,
									a.centro ,
									c.nomdepto
						  )
						  UNION
						  ( SELECT  a.empresa AS 'Empresa' ,
									9999999999 AS 'Codigo' ,
									c.nomdepto AS 'Nombre' ,
									a.centro AS 'Centro'
							FROM    @tmp_recosteo_detalle_kardex AS a
									INNER JOIN dbo.centros AS c ON a.empresa = c.empresa
																  AND a.centro = c.centro
							GROUP BY a.empresa ,
									a.centro ,
									c.nomdepto
						  )
						  UNION
						  ( SELECT  a.empresa AS 'Empresa' ,
									88888888888 AS 'Codigo' ,
									c.nomdepto AS 'Nombre' ,
									a.centro AS 'Centro'
							FROM    @tmp_recosteo_detalle_kardex AS a
									INNER JOIN dbo.centros AS c ON a.empresa = c.empresa
																  AND a.centro = c.centro
							GROUP BY a.empresa ,
									a.centro ,
									c.nomdepto
						  )
						  UNION
						  ( SELECT  a.empresa AS 'Empresa' ,
									77777777777 AS 'Codigo' ,
									'TOTAL GENERAL' AS 'Nombre' ,
									'99999999999999' AS 'Centro'
							FROM    @tmp_recosteo_detalle_kardex AS a
							GROUP BY a.empresa--,a.centro,c.nomdepto
	                                
						  )
						) AS table_
				ORDER BY Empresa ,
						centro ,
						Codigo
	END
	ELSE BEGIN
		INSERT  INTO dbo.tmp_detalleResumido
            ( empresa ,
              codigo ,
              nombre ,
              centro
            ) 
		SELECT  empresa ,
                codigo ,
                nombre ,
                centro
        FROM    ( --(
						  ( SELECT  a.empresa AS 'Empresa' ,
									9999999999 AS 'Codigo' ,
									c.nomdepto AS 'Nombre' ,
									a.centro AS 'Centro'
							FROM    @tmp_recosteo_detalle_kardex AS a
									INNER JOIN dbo.centros AS c ON a.empresa = c.empresa
																  AND a.centro = c.centro
							GROUP BY a.empresa ,
									a.centro ,
									c.nomdepto
						  )
						  UNION
						  ( SELECT  a.empresa AS 'Empresa' ,
									77777777777 AS 'Codigo' ,
									'TOTAL GENERAL' AS 'Nombre' ,
									'99999999999999' AS 'Centro'
							FROM    @tmp_recosteo_detalle_kardex AS a
							GROUP BY a.empresa--,a.centro,c.nomdepto
	                                
						  )
						) AS table_
				ORDER BY Empresa ,
						centro ,
						Codigo
	END	
    
    SET @counter = 1
    
    DECLARE @sql udtStringSize8000
    DECLARE @sql2 udtStringSize8000
    
    WHILE @counter <= @totalRows 
        BEGIN
            SET @sql = ( 'UPDATE a set [' + ( SELECT    LTRIM(STR(num_conc))
                                              FROM      dbo.tmp_concs
                                              WHERE     serial = @counter
                                            ) + '] = b.importe'
                         + ' from dbo.tmp_detalleResumido as a '
                         + ' inner join dbo.tmp_detalle2 as b on a.codigo=b.codigo and a.centro=b.centro '
                         + ' where b.num_conc='
                         + ( SELECT LTRIM(STR(num_conc))
                             FROM   dbo.tmp_concs
                             WHERE  serial = @counter
                           ) )
            SET @sql2 = ( 'UPDATE a set [' + ( SELECT   LTRIM(STR(num_conc))
                                               FROM     dbo.tmp_concs
                                               WHERE    serial = @counter
                                             )
                          + '] = (select sum(importe) from dbo.tmp_detalle2 where centro = a.centro and '
                          + ' num_conc=' + +( SELECT    LTRIM(STR(num_conc))
                                              FROM      dbo.tmp_concs
                                              WHERE     serial = @counter
                                            ) + ')'
                          + ' from dbo.tmp_detalleResumido as a '
                          + ' where codigo=9999999999' )
            EXEC( @sql )
            EXEC( @sql2 )
            SET @sql = '' 
            SET @counter = @counter + 1
        END
	
	--SELECT * FROM dbo.tmp_detalleResumido
	DECLARE @SQLFinal udtStringSize8000
	IF @tipoReporte = 0 BEGIN
		SET @SQLFinal = 'Select case when  (a.codigo = 0 or a.codigo = 88888888888) then '''' when a.codigo = 9999999999 then ''TOTALES'' else ltrim(str(a.codigo)) end as Cdigo,'
						+'case when  (a.codigo = 9999999999 or a.codigo = 88888888888) then null else a.nombre end as ''Nombre del empleado'','
						+'rtrim(b.rfcalfa) + ''-'' + ltrim(str(b.rfcnum)) + ''-'' + rtrim(b.rfchomo) as ''R.F.C'','
						+'rtrim(b.afiliacion) + ''-'' + rtrim(b.digvera) as ''No Afiliacin'','
						+'rtrim(b.sindicato) as ''Sindicato'','
						+'rtrim(c.clase) as ''Clase'','
						+'case when  (a.codigo = 9999999999 or a.codigo = 88888888888 or a.codigo = 0) then null else rtrim(a.centro) end as ''Centro'','
						+'case when  (a.codigo = 9999999999 or a.codigo = 88888888888 or a.codigo = 0) then null else rtrim(d.nomdepto) end as ''Nombre del c.c.'','
						+'e.ocupacion as ''Tabulador'','
						+'e.actividad as ''Ocupacin'','
						+'convert(nvarchar(30), b.fchalta, 103 ) as Alta,'
						+'b.sueldo as Sueldo,'
						+'b.saldiaint as Integrado'
						+@namesString
						+' FROM dbo.tmp_detalleResumido as a '
						+' LEFT JOIN empleados as b on a.empresa=b.empresa and a.codigo=b.codigo '
						+' LEFT JOIN llaves as c on b.empresa=c.empresa and b.codigo=c.codigo '
						+' LEFT JOIN centros as d on a.empresa=d.empresa and a.centro=d.centro '
						+' LEFT JOIN tabulador as e on c.empresa=e.empresa and c.ocupacion=e.ocupacion ' 
    END 
    ELSE BEGIN
		SET @SQLFinal = 'Select a.centro as Centro,case when  (a.codigo = 88888888888) then null else a.nombre end as ''Departamento'' '
						+@namesString
						+' FROM dbo.tmp_detalleResumido as a '
						+' LEFT JOIN empleados as b on a.empresa=b.empresa and a.codigo=b.codigo '
						+' LEFT JOIN llaves as c on b.empresa=c.empresa and b.codigo=c.codigo '
						+' LEFT JOIN centros as d on a.empresa=d.empresa and a.centro=d.centro '
						+' LEFT JOIN tabulador as e on c.empresa=e.empresa and c.ocupacion=e.ocupacion '
	END 
    
	
    EXEC(@SQLFinal)
        
    
    IF OBJECT_ID('dbo.tmp_concs') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_concs
        END
    IF OBJECT_ID('dbo.tmp_detalleResumido') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_detalleResumido
        END
    
GO
	

UPDATE  costeo_porcentaje
SET     porcentaje = 100
WHERE   porcentaje IS NULL
        AND serial = 1
GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RecosteoPorcentajePeriodo')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RecosteoPorcentajePeriodo
GO


CREATE PROCEDURE dbo.Obten_RecosteoPorcentajePeriodo
    (
      @empresa udtInteger ,
      @tiponom udtInteger,
	  @periodo udtinteger,
	  @ayo udtinteger,
	  @todas int
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    SET NOCOUNT ON 
    SET DATEFORMAT DMY

	select	a.empresa,
			a.codigo,
			rtrim(b.ap_paterno) + ' ' + rtrim(b.ap_materno) + ' ' + rtrim(b.nombre) as nombre,
			a.centro,
			c.nomdepto,
			a.porcentaje 
	from dbo.costeo_porcentaje as a
	inner join dbo.empleados as b on b.empresa=a.empresa and b.codigo=a.codigo
	inner join dbo.centros as c on c.empresa=a.empresa and  c.centro=a.centro
	where	case when @todas=1 then 0 else a.empresa end = case when @todas=1 then 0 else @empresa end 
			and a.tiponom=@tiponom
			and a.periodo=@periodo
			and a.ayo_operacion=@ayo

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.RecosteoVerificaPeriodo')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.RecosteoVerificaPeriodo
GO


CREATE PROCEDURE dbo.RecosteoVerificaPeriodo
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @periodoImportar int=0,
	  @aoImportar int=0
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    SET NOCOUNT ON 
    SET DATEFORMAT DMY

	DECLARE @tipo udtInteger ,
        @cTipo udtName ,
        @cMes udtName

	SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa
    
    IF @tipo = 1 
        BEGIN
            SET @cTipo = 'MES'
        END 
    ELSE 
        BEGIN
            SET @cTipo = 'PER'
        END

	select	isnull((
			select top 1 1 as Existe
			FROM    dbo.costeo_porcentaje AS a
			WHERE   a.empresa = @empresa
					AND a.tiponom = @tiponom
					AND a.periodo = @periodoImportar
					AND a.ayo_operacion = @aoImportar
					AND a.tipo = @cTipo
			),0) as Existe

GO

IF OBJECT_ID('dbo.RecosteoExtraeImportes') IS NOT NULL
begin
    DROP FUNCTION [dbo].[RecosteoExtraeImportes]
end
GO

CREATE FUNCTION [dbo].[RecosteoExtraeImportes](@empresa int,@tiponom int,@periodo int,@ao int,@TipoConcepto int)

RETURNS @Importes table(empresa int,codigo int, centro varchar(500), num_conc int,concepto varchar(250),mes varchar(10),porcentaje int,PorcEvaluar decimal(12,2),importe decimal(12,2), ImporteRecosteado decimal(12,4),TipoConc int,Percepciones decimal(12,4),Deducciones decimal(12,4),Neto decimal(12,4), Provisiones decimal(12,4),Folio int,Serial Int,modificado varchar(5),cTipo varchar(5))

AS

BEGIN

--declare @empresa int=1 ,
--		@tiponom int=1,
--		@periodo int=15,
--		@ao int=2022,
--		@totales int=0

DECLARE @tipo int ,
        @cTipo varchar(5),
        @cMes varchar(5)
        
    SELECT  @tipo = tipo
    FROM    dbo.costeo_parametros
    WHERE   empresa = @empresa

    IF @tipo = 0 
        BEGIN
            SET @cTipo = 'MES'
            SET @cMes = CASE WHEN @periodo = 01 THEN 'ENE'
                             WHEN @periodo = 02 THEN 'FEB'
                             WHEN @periodo = 03 THEN 'MAR'
                             WHEN @periodo = 04 THEN 'ABR'
                             WHEN @periodo = 05 THEN 'MAY'
                             WHEN @periodo = 06 THEN 'JUN'
                             WHEN @periodo = 07 THEN 'JUL'
                             WHEN @periodo = 08 THEN 'AGO'
                             WHEN @periodo = 09 THEN 'SEP'
                             WHEN @periodo = 10 THEN 'OCT'
                             WHEN @periodo = 11 THEN 'NOV'
                             WHEN @periodo = 12 THEN 'DIC'
                        END + SUBSTRING(LTRIM(RTRIM(STR(@AO))), 3, 2)
        END 
    ELSE 
        BEGIN
            SET @cMes = ''
            SET @cTipo = 'PER'
        END

    --select @cMes as cMes,@cTipo as cTipo

	declare @tmp_recosteo_detalle_empleados as table
        (
          empresa INT ,
          codigo INT ,
          centro VARCHAR(50) ,
          porcentaje INT ,
          serial BIGINT ,
          modificado VARCHAR(5)
        )


    INSERT  INTO @tmp_recosteo_detalle_empleados
            SELECT  a.empresa ,
                    a.codigo ,
                    a.centro ,
                    a.porcentaje ,
                    a.serial ,
                    a.modificado
            FROM    dbo.costeo_porcentaje AS a
            WHERE   a.empresa = @empresa
                    AND a.periodo = @periodo
                    AND a.ayo_operacion = @ao
                    --AND a.tipo = @cTipo
			order by a.empresa,a.codigo,a.serial
	--select * from @tmp_recosteo_detalle_empleados
	--update @tmp_recosteo_detalle_empleados set 
	insert into @Importes
	Select	empresa,codigo,centro,num_conc,concepto,mes,porcentaje,PorcEvaluar,
			importe,ImporteRecosteado,TipoConc,
			sum(case when TipoConc=1 then ImporteRecosteado else 0 end) OVER ( PARTITION  BY empresa,codigo,centro) as Percepciones,
			sum(case when TipoConc=2 then ImporteRecosteado else 0 end) OVER ( PARTITION  BY empresa,codigo,centro) as Deducciones,
			sum(case when TipoConc=1 then ImporteRecosteado else 0 end) OVER ( PARTITION  BY empresa,codigo,centro) -
			sum(case when TipoConc=2 then ImporteRecosteado else 0 end) OVER ( PARTITION  BY empresa,codigo,centro)  as Neto,
			sum(case when TipoConc=3 then ImporteRecosteado else 0 end) OVER ( PARTITION  BY empresa,codigo,centro) as Provisiones,
			folio,
			serial,
			modificado,
			@cTipo cTipo
	from(
			select	a.empresa,
					a.codigo,
					a.centro,
					b.num_conc,
					b.concepto,
					b.mes,
					a.porcentaje,
					b.importe,
					convert(decimal(12,4),
											(convert(decimal(12,4),b.importe) * convert(decimal(12,2),convert(decimal(12,2),a.porcentaje)/100))
					) as ImporteRecosteado,
					b.TipoConc,
					b.folio,
					dense_rank() over (partition  by b.codigo,b.TipoConc order by b.num_conc,b.folio,b.justificar ) as serial,
					convert(decimal(12,2),convert(decimal(12,2),a.porcentaje)/100) PorcEvaluar,
					a.modificado
			from @tmp_recosteo_detalle_empleados as a
			outer apply (
							select	K.empresa,
									k.codigo,
									k.num_conc,
									k.concepto,
									k.importe,
									k.mes,
									case	when ((k.num_conc between 1 and 99) or (k.num_conc between 501 and 599) OR (k.num_conc between 1101 and 1199)) then 1 
											when ((k.num_conc between 101 and 199) or (k.num_conc between 601 and 699) OR (k.num_conc between 1001 and 1099)) then 2
									else 3
									end as TipoConc,
									k.Folio,
									k.justificar
							from dbo.kardex_anual as k
							where	k.empresa=a.empresa
									and k.codigo=a.codigo
									and ( (@cTipo='PER' and k.periodo=@periodo) or (@cTipo='MES' and k.mes=@cMes) )
									and k.ayo_operacion=@ao
									and k.tiponom=@tiponom
									and k.nomina='ORD'
							--order by k.empresa,k.codigo,k.num_conc,k.folio
						) as b
		) as tbl
		where (TipoConc=@TipoConcepto or @TipoConcepto=0) and not num_conc is null
		order by empresa,codigo,centro,TipoConc,serial
  

  RETURN 

END


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RecosteoExtraerPoliza_2022')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RecosteoExtraerPoliza_2022
GO

CREATE PROCEDURE dbo.Obten_RecosteoExtraerPoliza_2022
(
    @empresa int=1 ,
	@tiponom int=1,
	@periodo int=15,
	@ao int=2022,
	@totales int=0
     
)
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

		declare @Importes as table(empresa int,codigo int, centro varchar(500), num_conc int,concepto varchar(250),mes varchar(10),porcentaje int,PorcEvaluar decimal(12,2),importe decimal(12,2), ImporteRecosteado decimal(12,4),TipoConc int,Percepciones decimal(12,4),Deducciones decimal(12,4),Neto decimal(12,4), Provisiones decimal(12,4),Folio int,Serial Int,modificado varchar(5),cTipo varchar(5))

		DECLARE @tmp_polizaRecosteada TABLE
        (
          [empresa] [int] NOT NULL ,
          --[codigo] [Bigint] NOT NULL ,
		  [codigo] [varchar](50) NOT NULL ,
          [nombreEmpleado] [varchar](300) NULL ,
          [afiliacionEmpleado] [varchar](35) NULL ,
          [curpEmpleado] [varchar](30) NULL ,
          [departamentoEmpleado] [Varchar](15) NULL ,
          [nombreDepartamentoEmpleado] [varchar](200) NULL ,
          [cuentaEmpleado] [varchar](30) NULL ,
          [numeroOcupacion] [int] NULL ,
          [actividadEmpleado] [varchar](100) NULL ,
          [fechaAltaEmpleado] [nvarchar](30) NULL ,
          [fechaAntiguedadEmpleado] [varchar](30) NULL ,
          [tipoSalarioEmpleado] [varchar](30) NULL ,
          [jornadaEmpleado] [varchar](30) NULL ,
          [ultimoSueldoEmpleado] [Varchar](35) NULL ,
          [ultimoSBCEmpleado] [Varchar](35) NULL ,
          [claseEmpleado] [varchar](30) NULL ,
          [numeroConceptoPercepcion] [int] NULL ,
          [nombreConceptoPercepcion] [varchar](100) NULL ,
          [importeConceptoPercepcion] [numeric](10, 2) NULL ,
          [numeroConceptoDeduccion] [int] NULL ,
          [nombreConceptoDeduccion] [varchar](100) NULL ,
          [importeConceptoDeduccion] [numeric](10, 2) NULL ,
          [numeroConceptoProvision] [int] NULL ,
          [nombreConceptoProvision] [varchar](100) NULL ,
          [importeConceptoProvision] [numeric](10, 2) NULL ,
          [totalPercepcionesEmpleado] [numeric](38, 2) NULL ,
          [totalDeduccionesEmpleado] [numeric](38, 2) NULL ,
          [totalprovisionesEmpleado] [numeric](38, 2) NULL ,
          [netoPagarEmpleado] [numeric](38, 2) NULL ,
          [serial] [Bigint] NOT NULL ,
          [grupo] [varchar](100) NOT NULL ,
          [nombreGrupo] [varchar](200) NULL ,
          [modificado] [varchar](2) NULL ,
          [periodo] [varchar](250) NULL ,
		  [codigoOrden] [bigint] NOT NULL ,
          PRIMARY KEY NONCLUSTERED ( empresa, codigoOrden, serial, grupo )
        )

		insert into @Importes
		select * from [dbo].[RecosteoExtraeImportes](@empresa,@tiponom,@periodo,@ao,0)

		Declare @seriales as table(Empresa int, serial int,codigo int,centro varchar(250),percepciones decimal(12,2),deducciones decimal(12,2),Neto decimal(12,2),Provisiones decimal(12,2),modificado varchar(5),ctipo varchar(5))
		Declare @met int=1
		while @met<=25
		begin
			insert into @seriales(empresa,serial,codigo,centro,modificado,ctipo)
			--values(@empresa,@met)
			select distinct empresa,@met,codigo,centro,modificado,ctipo--,sum(percepciones),sum(deducciones),sum(neto),sum(Provisiones)
			from @Importes
			--group by empresa,codigo,centro

			set @met+=1
		end
		--select * from @seriales
		update a set	percepciones= b.Percepciones,
						deducciones=b.Deducciones,
						neto=b.Neto,
						Provisiones=b.Provisiones
		from @seriales as a
		outer apply (select top 1 percepciones,deducciones,Neto,Provisiones from @Importes where empresa=a.empresa and codigo=a.codigo and centro=a.centro) as b
		
		if @totales=1
		begin 
			insert into @tmp_polizaRecosteada
			select	a.empresa,
					a.codigo,
					convert(varchar,a.codigo) + ' ' + trim(em.ap_paterno) + ' ' + trim(em.ap_paterno) + ' ' + trim(em.nombre) as nombreEmpleado,
					trim(em.afiliacion) + '-' + trim(em.digvera) as afiliacionEmpleado,
					em.curp as curpEmpleado,
					a.centro as departamentoEmpleado,
					trim(a.centro) + ' ' + trim(cn.nomdepto) as nombreDepartamentoEmpleado,
					'Cta. ' + RTRIM(em.cta_bco_no) cuentaEmpleado,
					t.ocupacion numeroOcupacion,
					t.actividad actividadEmpleado,
					 'Fecha de Ingreso: ' + CONVERT(NVARCHAR(20), em.fchalta, 103) fechaAltaEmpleado,
					CONVERT(NVARCHAR(20), em.fchantigua, 103) fechaAntiguedadEmpleado,
					'Tipo de salario: '
										+ CASE WHEN em.tiposal = 0 THEN '0. Fijo'
												WHEN em.tiposal = 1 THEN '1. Variable'
												WHEN em.tiposal = 2 THEN '2. Mixto'
											END tipoSalarioEmpleado,
					'Jornada: '
								+ CASE WHEN em.jornada = 0 THEN '0. Normal'
										WHEN em.jornada = 1 THEN '1. Reducida'
									END jornadaEmpleado,
					'Ultimo: Sdo Diario $'+ CAST(em.sueldo AS VARCHAR(30)) ultimoSueldoEmpleado,
					'S.B.C. IMSS $'	+ CAST(em.saldiaint AS VARCHAR(30)) ultimoSBCEmpleado ,
					'Classe: ' + RTRIM(l.clase) claseEmpleado,
					b.num_conc numeroConceptoPercepcion,
					b.concepto nombreConceptoPercepcion,
					b.ImporteRecosteado as importeConceptoPercepcion,
					c.num_conc as numeroConceptoDeduccion,
					c.concepto as nombreConceptoDeduccion,
					c.ImporteRecosteado as importeConceptoDedidccion,
					d.num_conc as numeroConceptoProvision,
					d.concepto as nombreConceptoProvision,
					d.ImporteRecosteado as importeConceptoProvision,
					a.percepciones as totalPercepcionesEmpleado,
					a.deducciones as totalDeduccionesEmpleado,
					a.Provisiones as totalProvisionesEmpleado,
					a.Neto as netoPagarEmpleado,
					a.serial,
					a.centro as grupo,
					cn.nomdepto as nombreGrupo,
					a.modificado,
					CASE WHEN a.cTipo = 'PER' THEN 'Periodo: '
												WHEN a.cTipo = 'MES' THEN 'Mes: '
											END + convert(varchar,@periodo) + ' '+ convert(varchar,@ao) as periodo,
					a.codigo as CodigoOrden
			from @seriales as a
			inner join dbo.empleados as em on em.empresa=a.empresa and em.codigo=a.codigo
			inner join dbo.llaves as l on l.empresa=a.empresa and l.codigo=a.codigo
			inner join dbo.centros as cn on cn.empresa=a.empresa and cn.centro=a.centro
			inner join dbo.tabulador as t on t.empresa=l.empresa and t.ocupacion=l.ocupacion
			left join @Importes as b on b.empresa=a.empresa and b.codigo=a.codigo and b.centro=a.centro and b.serial=a.serial and b.TipoConc=1
			left join @Importes as c on c.empresa=a.empresa and c.codigo=a.codigo and c.centro=a.centro and c.serial=a.serial and c.TipoConc=2
			left join @Importes as d on d.empresa=a.empresa and d.codigo=a.codigo and d.centro=a.centro and d.serial=a.serial and d.TipoConc=3
			where isnull(isnull(b.Serial,c.Serial),d.serial)>0
			order by a.empresa,a.centro,a.codigo,serial
		end
		
		--Totales por departamento
		insert into @tmp_polizaRecosteada
		select	a.empresa,
				'' as Codigo,
				'Total Departamento: ' + trim(a.centro)+ ' ' + rtrim(cn.nomdepto) as nombreEmpleado,
				'' as afiliacionEmpleado,
				'' as curpEmpleado,
				a.centro as departamentoEmpleado,
				cn.nomdepto as nombreDepartamentoEmpleado,
				'' cuentaEmpleado,
				null numeroOcupacion,
				'' actividadEmpleado,
				'' fechaAltaEmpleado,
				'' fechaAntiguedadEmpleado,
				'' tipoSalarioEmpleado,
				'' jornadaEmpleado,
				'' ultimoSueldoEmpleado,
				'' ultimoSBCEmpleado ,
				'' claseEmpleado,
				max(b.num_conc) numeroConceptoPercepcion,
				max(b.concepto) nombreConceptoPercepcion,
				sum(b.ImporteRecosteado) as importeConceptoPercepcion,
				max(c.num_conc) as numeroConceptoDeduccion,
				max(c.concepto) as nombreConceptoDeduccion,
				sum(c.ImporteRecosteado) as importeConceptoDedidccion,
				max(d.num_conc) as numeroConceptoProvision,
				max(d.concepto) as nombreConceptoProvision,
				sum(d.ImporteRecosteado) as importeConceptoProvision,
				sum(a.percepciones) as totalPercepcionesEmpleado,
				sum(a.deducciones) as totalDeduccionesEmpleado,
				sum(a.Provisiones) as totalProvisionesEmpleado,
				sum(a.Neto) as netoPagarEmpleado,
				a.serial,
				a.centro as grupo,
				cn.nomdepto as nombreGrupo,
				'' modificado,
				max(CASE WHEN a.cTipo = 'PER' THEN 'Periodo: '
											WHEN a.cTipo = 'MES' THEN 'Mes: '
										END + convert(varchar,@periodo) + ' '+ convert(varchar,@ao)) as periodo,
				999999999 as CodigoOrden
		from @seriales as a
		--inner join dbo.empleados as em on em.empresa=a.empresa and em.codigo=a.codigo
		--inner join dbo.llaves as l on l.empresa=a.empresa and l.codigo=a.codigo
		inner join dbo.centros as cn on cn.empresa=a.empresa and cn.centro=a.centro
		--inner join dbo.tabulador as t on t.empresa=l.empresa and t.ocupacion=l.ocupacion
		left join @Importes as b on b.empresa=a.empresa and b.codigo=a.codigo and b.centro=a.centro and b.serial=a.serial and b.TipoConc=1
		left join @Importes as c on c.empresa=a.empresa and c.codigo=a.codigo and c.centro=a.centro and c.serial=a.serial and c.TipoConc=2
		left join @Importes as d on d.empresa=a.empresa and d.codigo=a.codigo and d.centro=a.centro and d.serial=a.serial and d.TipoConc=3
		where isnull(isnull(b.Serial,c.Serial),d.serial)>0
		group by a.empresa,a.centro,cn.nomdepto,a.serial
		--order by a.empresa,a.centro,a.codigo,serial

		--Total general
		insert into @tmp_polizaRecosteada
		select	a.empresa,
				'' as Codigo,
				'Total General: '  as nombreEmpleado,
				'' as afiliacionEmpleado,
				'' as curpEmpleado,
				'' as departamentoEmpleado,
				'' as nombreDepartamentoEmpleado,
				'' cuentaEmpleado,
				null numeroOcupacion,
				'' actividadEmpleado,
				'' fechaAltaEmpleado,
				'' fechaAntiguedadEmpleado,
				'' tipoSalarioEmpleado,
				'' jornadaEmpleado,
				'' ultimoSueldoEmpleado,
				'' ultimoSBCEmpleado ,
				'' claseEmpleado,
				max(b.num_conc) numeroConceptoPercepcion,
				max(b.concepto) nombreConceptoPercepcion,
				sum(b.ImporteRecosteado) as importeConceptoPercepcion,
				max(c.num_conc) as numeroConceptoDeduccion,
				max(c.concepto) as nombreConceptoDeduccion,
				sum(c.ImporteRecosteado) as importeConceptoDedidccion,
				max(d.num_conc) as numeroConceptoProvision,
				max(d.concepto) as nombreConceptoProvision,
				sum(d.ImporteRecosteado) as importeConceptoProvision,
				sum(a.percepciones) as totalPercepcionesEmpleado,
				sum(a.deducciones) as totalDeduccionesEmpleado,
				sum(a.Provisiones) as totalProvisionesEmpleado,
				sum(a.Neto) as netoPagarEmpleado,
				a.serial,
				'99999999999997 ' as grupo,
				'' as nombreGrupo,
				'' modificado,
				max(CASE WHEN a.cTipo = 'PER' THEN 'Periodo: '
											WHEN a.cTipo = 'MES' THEN 'Mes: '
										END + convert(varchar,@periodo) + ' '+ convert(varchar,@ao)) as periodo,
				9999999999 as CodigoOrden
		from @seriales as a
		--inner join dbo.empleados as em on em.empresa=a.empresa and em.codigo=a.codigo
		--inner join dbo.llaves as l on l.empresa=a.empresa and l.codigo=a.codigo
		--inner join dbo.centros as cn on cn.empresa=a.empresa and cn.centro=a.centro
		--inner join dbo.tabulador as t on t.empresa=l.empresa and t.ocupacion=l.ocupacion
		left join @Importes as b on b.empresa=a.empresa and b.codigo=a.codigo and b.centro=a.centro and b.serial=a.serial and b.TipoConc=1
		left join @Importes as c on c.empresa=a.empresa and c.codigo=a.codigo and c.centro=a.centro and c.serial=a.serial and c.TipoConc=2
		left join @Importes as d on d.empresa=a.empresa and d.codigo=a.codigo and d.centro=a.centro and d.serial=a.serial and d.TipoConc=3
		where isnull(isnull(b.Serial,c.Serial),d.serial)>0
		group by a.empresa,a.serial

		select * 
		from @tmp_polizaRecosteada
		order by empresa,grupo,codigoOrden,serial
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_RecosteoExtraerNomina_2022')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_RecosteoExtraerNomina_2022
GO

CREATE PROCEDURE dbo.Obten_RecosteoExtraerNomina_2022
(
    @empresa int=1 ,
	@tiponom int=1,
	@periodo int=15,
	@ao int=2022,
	@tipoReporte int=0
     
)
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

		IF OBJECT_ID('dbo.tmp_recosteo_importes') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_recosteo_importes
        END

		create table dbo.tmp_recosteo_importes (empresa int,codigo varchar(15), centro varchar(20), num_conc int,concepto varchar(250),mes varchar(10),porcentaje int,
												PorcEvaluar decimal(12,2),importe decimal(12,2), ImporteRecosteado decimal(12,2),TipoConc int,Percepciones decimal(12,4),
												Deducciones decimal(12,4),Neto decimal(12,4), Provisiones decimal(12,4),Folio int,Serial Int,modificado varchar(5),cTipo varchar(5),
												CodigoOrdenar bigint, tipoReg int,
												RFC varchar(15),Afiliacion varchar(15),Sindicato varchar(5),Clase varchar(5),nombdepto varchar(50),ocupacion varchar(5),
												Actividad varchar(100),Alta varchar(10), Sueldo varchar(15),Saldiaint varchar(15),cuenta varchar(20),Nombre varchar(300))

		--Extraer datos de kardex_anual desde funcion
		insert into dbo.tmp_recosteo_importes
		select	a.empresa,convert(varchar(50),a.codigo),a.centro,a.num_conc,a.concepto,a.mes,a.porcentaje,a.PorcEvaluar,a.importe,a.ImporteRecosteado,
				a.TipoConc,a.Percepciones,a.Deducciones,a.Neto,a.Provisiones,a.Folio,a.Serial,a.modificado,a.cTipo,a.codigo,1 tipoReg,
				trim(em.rfcalfa) + '-' + convert(varchar,isnull(em.rfcnum,0)) + '-' + trim(em.rfchomo) as RFC,
				trim(em.afiliacion) + '-' + trim(em.digvera) as afiliacionEmpleado,
				em.sindicato,
				l.clase,
				trim(cn.nomdepto) as nombreDepartamento,
				t.ocupacion numeroOcupacion,
				t.actividad actividadEmpleado,
				CONVERT(NVARCHAR(20), em.fchalta, 103) Alta,
				CAST(em.sueldo AS VARCHAR(30)) ultimoSueldoEmpleado,
				CAST(em.saldiaint AS VARCHAR(30)) ultimoSBCEmpleado ,
				RTRIM(em.cta_bco_no) cuentaEmpleado,
				trim(em.ap_paterno) + ' ' + trim(em.ap_materno) + ' ' +  trim(em.nombre) as Nombre
		from [dbo].[RecosteoExtraeImportes](@empresa,@tiponom,@periodo,@ao,0) as a
		inner join dbo.empleados as em on em.empresa=a.empresa and em.codigo=a.codigo
		inner join dbo.llaves as l on l.empresa=a.empresa and l.codigo=a.codigo
		inner join dbo.centros as cn on cn.empresa=a.empresa and cn.centro=a.centro
		inner join dbo.tabulador as t on t.empresa=l.empresa and t.ocupacion=l.ocupacion
		--where a.codigo=300041

		--Agregar totales por empleado
		insert into dbo.tmp_recosteo_importes
		select	distinct
				empresa,convert(varchar(50),codigo),centro,10000 num_conc,'TOTAL PERCEPCIONES',mes,porcentaje,PorcEvaluar,Percepciones importe,Percepciones ImporteRecosteado,
				1,Percepciones,Deducciones,Neto,Provisiones,1 Folio,1 Serial,modificado,cTipo,codigo,1 tipoReg,
				RFC,Afiliacion,Sindicato,Clase,nombdepto,ocupacion,Actividad,Alta,Sueldo,Saldiaint,cuenta,Nombre
		from dbo.tmp_recosteo_importes

		insert into dbo.tmp_recosteo_importes
		select	distinct
				empresa,convert(varchar(50),codigo),centro,20000 num_conc,'TOTAL DEDUCCIONES',mes,porcentaje,PorcEvaluar,Deducciones importe,Deducciones ImporteRecosteado,
				2,Percepciones,Deducciones,Neto,Provisiones,1 Folio,1 Serial,modificado,cTipo,codigo,1 tipoReg,
				RFC,Afiliacion,Sindicato,Clase,nombdepto,ocupacion,Actividad,Alta,Sueldo,Saldiaint,cuenta,Nombre
		from dbo.tmp_recosteo_importes

		insert into dbo.tmp_recosteo_importes
		select	distinct
				empresa,convert(varchar(50),codigo),centro,20001 num_conc,'NETO',mes,porcentaje,PorcEvaluar,Neto importe,Neto ImporteRecosteado,
				2,Percepciones,Deducciones,Neto,Provisiones,1 Folio,1 Serial,modificado,cTipo,codigo,1 tipoReg,
				RFC,Afiliacion,Sindicato,Clase,nombdepto,ocupacion,Actividad,Alta,Sueldo,Saldiaint,cuenta,Nombre
		from dbo.tmp_recosteo_importes

		insert into dbo.tmp_recosteo_importes
		select	distinct
				empresa,convert(varchar(50),codigo),centro,30000 num_conc,'TOTAL PROVISIONES',mes,porcentaje,PorcEvaluar,Provisiones importe,Provisiones ImporteRecosteado,
				3,Percepciones,Deducciones,Neto,Provisiones,1 Folio,1 Serial,modificado,cTipo,codigo,1 tipoReg,
				RFC,Afiliacion,Sindicato,Clase,nombdepto,ocupacion,Actividad,Alta,Sueldo,Saldiaint,cuenta,Nombre
		from dbo.tmp_recosteo_importes
		--group by empresa,centro,codigo

		--Agregar los encabezados por departamento
		insert into dbo.tmp_recosteo_importes
		select	distinct
				empresa,'' codigo,centro,num_conc,concepto,'' mes,null porcentaje,null PorcEvaluar,null importe,null ImporteRecosteado,
				TipoConc,null Percepciones,null Deducciones,null Neto,null Provisiones,1 Folio,1 Serial,'' modificado,cTipo, 0 codigo,0 tipoReg,
				'' RFC,'' Afiliacion,'' Sindicato,'' Clase,nombdepto,'' ocupacion,'' Actividad,'' Alta,'' Sueldo,'' Saldiaint,'' cuenta,centro + ' ' + nombdepto as Nombre
		from dbo.tmp_recosteo_importes
		where	tipoReg=1
				and @tipoReporte=0 --si es detallado
		group by empresa,centro,nombdepto,num_conc,concepto,TipoConc,cTipo

		--Agregar los totales por departamento
		insert into dbo.tmp_recosteo_importes
		select	distinct
				empresa,iif(@tipoReporte=0,'TOTAL:','') codigo,centro,num_conc,concepto,'' mes,null porcentaje,null PorcEvaluar,sum(importe) importe,sum(ImporteRecosteado) importeRecosteado,
				TipoConc,sum(Percepciones),sum(Deducciones),sum(Neto),sum(Provisiones),1 Folio,1 Serial,'' modificado,cTipo, 999999998 codigo,2 tipoReg,
				'' RFC,'' Afiliacion,'' Sindicato,'' Clase,nombdepto,'' ocupacion,'' Actividad,'' Alta,'' Sueldo,'' Saldiaint,'' cuenta,centro + ' ' + nombdepto as Nombre
		from dbo.tmp_recosteo_importes
		where tipoReg=1
		group by empresa,centro,nombdepto,num_conc,concepto,TipoConc,cTipo

		--Agregar registros en blanco por departamento
		insert into dbo.tmp_recosteo_importes
		select	distinct
				empresa,'' codigo,centro,num_conc,concepto,'' mes,null porcentaje,null PorcEvaluar,null importe,null ImporteRecosteado,
				TipoConc,null Percepciones,null Deducciones,null Neto,null Provisiones,1 Folio,1 Serial,'' modificado,cTipo, 999999999 codigo,3 tipoReg,
				'' RFC,'' Afiliacion,'' Sindicato,'' Clase,nombdepto,'' ocupacion,'' Actividad,'' Alta,'' Sueldo,'' Saldiaint,'' cuenta,'' as Nombre
		from dbo.tmp_recosteo_importes
		where	tipoReg=1
				and @tipoReporte=0 --si es detallado
		group by empresa,centro,nombdepto,num_conc,concepto,TipoConc,cTipo

		--Agregar total general
		insert into dbo.tmp_recosteo_importes
		select	distinct
				empresa,'' codigo,'99999999999997' centro,num_conc,concepto,'' mes,null porcentaje,null PorcEvaluar,sum(importe) importe,sum(ImporteRecosteado) importeRecosteado,
				TipoConc,sum(Percepciones) Percepciones,sum(Deducciones) Deducciones,sum(Neto) Neto,sum(Provisiones),1 Folio,999999999 Serial,'' modificado,cTipo, 9999999999 codigo,4 tipoReg,
				'' RFC,'' Afiliacion,'' Sindicato,'' Clase,'' nombdepto,'' ocupacion,'' Actividad,'' Alta,'' Sueldo,'' Saldiaint,'' cuenta,'TOTAL GENERAL'
		from dbo.tmp_recosteo_importes
		where tipoReg=1
		group by empresa,num_conc,concepto,TipoConc,cTipo

		Declare @conceptos as table(empresa int,num_conc int, concepto varchar(250), serial int)

		
		--Definir los conceptos
		insert into @conceptos
		select empresa,num_conc,concepto,dense_rank() over (partition  by empresa order by tipoconc, num_conc ) as serial
		from(
				(select	a.empresa,
						a.num_conc,
						max(concepto) as concepto,
						a.TipoConc
				from dbo.tmp_recosteo_importes as a
				group by a.empresa,a.num_conc,a.TipoConc)
			) as tbl
		order by empresa,TipoConc,num_conc


		--Armar los encabezados de conceptos
		Declare @max int,
				@met int=1
		set @max = isnull((select max(serial) from @conceptos),0)

		Declare @concepto varchar(max) = '',
				@nombreConcepto varchar(max)='',
				@encabezados1 varchar(max)='',
				@encabezados2 varchar(max)='',
				@encabezados3 varchar(max)=''
				

		declare @numerovariable int = 1
		declare @numerovariableEnc int = 1

		while @met<=@max
		begin 
			select	@concepto = convert(varchar,num_conc),
				 	@nombreConcepto = trim(concepto)
			from @conceptos
			where serial=@met
			--max(iif(num_conc=1,importeRecosteado,0)) as Sueldo
			if @numerovariable=1
			begin
				if len( @encabezados1 + 'iif(tiporeg in(0,3),null,max(iif(num_conc=' + @concepto + ',importeRecosteado,0))) as ['+@concepto+' '+@nombreConcepto+'],')<=8000
				begin
					set @encabezados1 += 'iif(tiporeg in(0,3),null,max(iif(num_conc=' + @concepto + ',importeRecosteado,0))) as ['+@concepto+' '+@nombreConcepto+'],'
				end
				else begin
					set @numerovariable+=1
				end
			end
			if @numerovariable=2
			begin
				if len( @encabezados2 + 'max(iif(num_conc=' + @concepto + ',importeRecosteado,0)) as ['+@nombreConcepto+'],')<=8000
				begin
					set @encabezados2 += 'max(iif(num_conc=' + @concepto + ',importeRecosteado,0)) as ['+@nombreConcepto+'],'
				end
				else begin
					set @numerovariable+=1
				end
			end
			if @numerovariable=3
			begin
				if len( @encabezados3 + 'max(iif(num_conc=' + @concepto + ',importeRecosteado,0)) as ['+@nombreConcepto+'],')<=8000
				begin
					set @encabezados3 += 'max(iif(num_conc=' + @concepto + ',importeRecosteado,0)) as ['+@nombreConcepto+'],'
				end
				else begin
					set @numerovariable+=1
				end
			end

			set @met+=1
		end

		--Armar el pivot
		Declare @sql varchar(max) = ''

		set @sql = ' SELECT '+ iif(@tipoReporte=0,
							'codigo ''Cdigo'',Nombre ''Nombre del empleado'',RFC ''R.F.C.'',Afiliacion ''No Afiliacin'',Sindicato,Clase,iif(tipoReg in(2,3,4),'''',Centro) as ''C.C.'', '+
							'iif(tipoReg in(2,3),'''',nombdepto)''Nombre del C.C'',ocupacion Tabulador,Actividad ''Ocupacinn'',Alta,Sueldo,Saldiaint Integrado, ',
							'iif(tipoReg in(4),'''',Centro)''C.C'',iif(tipoReg in(4),''TOTAL GENERAL'',nombdepto) as ''Nombre del C.C'',')+ 
							@encabezados1 + ''''' as ''.''' +
							--'max(iif(num_conc=1,importeRecosteado,0)) as Sueldo '+
							
					' FROM dbo.tmp_recosteo_importes '+
					iif(@tipoReporte=1, ' WHERE tiporeg<>1','')+
					iif(@TipoReporte=0,	' GROUP BY empresa,codigoOrdenar,codigo,Nombre,RFC,Afiliacion,Sindicato,Clase,Centro,nombdepto,tiporeg,ocupacion,Actividad,Alta,sueldo,saldiaint ',
										' GROUP BY empresa,Centro,nombdepto,tipoReg ') +
					iif(@TipoReporte=0,	' order by empresa,centro,tiporeg asc,codigoOrdenar',
										' order by empresa,centro' )


		exec(@sql)
		

		IF OBJECT_ID('dbo.tmp_recosteo_importes') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_recosteo_importes
        END
GO




